@@ -4,7 +4,6 @@
 __author__ = 'Jim Parsons (jparsons@redhat.com)'
                                                                                 
                                                                                 
-from gtk import TRUE, FALSE
 import string
 import os
 import gobject
@@ -61,14 +60,27 @@ FI_TYPE=_("Fence Device Type: \n %s")
 
 AFF_NODES=_("Affected Cluster Nodes")
 
+FD_DELETION_WARNING=_("Fence Device Deletion Warning")
+AFFECTED_CLUSTER_NODES=_("Affected Cluster Nodes")
 WARNING1=_("The following Cluster Node depends on Fence Device %s.")
-
 WARNINGS1=_("The following Cluster Nodes depend on Fence Device %s.")
-
 WARNING2=_("Removing this Fence Device will alter Fencing on this Cluster Node.\n Are you certain that you wish to continue?")
-
 WARNINGS2=_("Removing this Fence Device will alter Fencing on these Cluster Nodes.\n Are you certain that you wish to continue?")
 
+FAILDOM_DELETION_WARNING=_("Failover Domain Deletion Warning")
+AFFECTED_SERVICES=_("Affected Services")
+WARNING3=_("The following Service depends on Failover Domain %s.")
+WARNINGS3=_("The following Services depend on Failover Domain %s.")
+WARNING4=_("Removing this Failover Domain will alter this Service.\n Are you certain that you wish to continue?")
+WARNINGS4=_("Removing this Failover Domain will alter these Services.\n Are you certain that you wish to continue?")
+
+RESOURCE_DELETION_WARNING=_("Resource Deletion Warning")
+#AFFECTED_SERVICES=_("Affected Services")
+WARNING5=_("The following Service depends on Resource %s.")
+WARNINGS5=_("The following Services depend on Resource %s.")
+WARNING6=_("Removing this Resource will alter this Service.\n Are you certain that you wish to continue?")
+WARNINGS6=_("Removing this Resource will alter these Services.\n Are you certain that you wish to continue?")
+
 ADD_FENCE_DEVICE=_("Add a New Fence Device")
 
 EDIT_FENCE_DEVICE=_("Edit Properties for this Fence Device")
@@ -87,6 +99,8 @@ NEED_CLUSTER_NAME=_("Please provide a name for the cluster")
 
 NODE_UNIQUE_NAME=_("Names for Cluster Nodes must be Unique. Please choose another name for this Node.")
 
+NODE_NAME_EQUAL_TO_FD_NAME = _("There is a Fence Device named \"%s\". Cluster Nodes cannot have the same names as Fence Devices. Please choose another name for this Node.")
+
 NODE_NAME_REQUIRED=_("Please provide a name for this Cluster Node.")
 
 NODE_NAME_LENGTH_EXCEEDED=_("Node names may not exceed 64 characters. Please reduce the length of this node name")
@@ -111,7 +125,7 @@ SERVICE_NAME_REQUIRED=_("Please provide a name for this service.")
 
 UNIQUE_SERVICE_NAME=_("Services must have unique names. The name %s is already in use. Please provide a unique name.")
 
-CONFIRM_LEVEL_REMOVE=_("Are you certain that you wish to remove this fence level and all fences contained within it??")
+CONFIRM_LEVEL_REMOVE=_("Are you certain that you wish to remove this fence level and all fences contained within it?")
 
 CONFIRM_LEVEL_REMOVE_EMPTY=_("Are you certain that you wish to remove this fence level?")
 
@@ -227,7 +241,6 @@ class ConfigTabController:
     self.config_version = self.glade_xml.get_widget('config_version')
     self.post_join = self.glade_xml.get_widget('post_join')
     self.post_fail = self.glade_xml.get_widget('post_fail')
-    self.clean_start = self.glade_xml.get_widget('clean_start')
     self.mcast_interface = self.glade_xml.get_widget('mcast_interface')
     self.mcast_interface_entry = self.glade_xml.get_widget('mcast_interface_entry')
 
@@ -280,7 +293,6 @@ class ConfigTabController:
     self.glade_xml.get_widget('okbutton12').connect('clicked',self.on_fd_panel_ok)
 
     self.fd_delete = self.glade_xml.get_widget('fd_delete')
-    self.fd_delete.connect("delete_event",self.fd_delete_delete)
     self.fd_delete_warning1 = self.glade_xml.get_widget('fd_delete_warning1')
     self.fd_delete_warning2 = self.glade_xml.get_widget('fd_delete_warning2')
     self.fd_delete_treeview = self.glade_xml.get_widget('fd_delete_treeview')
@@ -289,17 +301,14 @@ class ConfigTabController:
                                               gobject.TYPE_STRING)
 
     self.fd_delete_treeview.set_model(self.fd_delete_treemodel)
-    self.fd_delete_treeview.set_headers_visible(TRUE)
+    self.fd_delete_treeview.set_headers_visible(True)
     self.fd_delete_treeview.get_selection().set_mode(gtk.SELECTION_NONE)
     self.fd_delete_treeview.get_selection().unselect_all()
 
     renderer0 = gtk.CellRendererText()
     column0 = gtk.TreeViewColumn(AFF_NODES,renderer0, text=0)
     self.fd_delete_treeview.append_column(column0)
-
-    self.glade_xml.get_widget('okbutton15').connect('clicked',self.on_fd_delete_ok)
-    self.glade_xml.get_widget('cancelbutton15').connect('clicked',self.on_fd_delete_cancel)
-
+    
     self.rc_options = self.glade_xml.get_widget('rc_options')
     self.rc_options.connect('changed',self.rc_optionmenu_change)
     self.prep_rc_options()
@@ -315,7 +324,7 @@ class ConfigTabController:
                                           gobject.TYPE_INT,
                                           gobject.TYPE_PYOBJECT)
     self.fence_treeview.set_model(self.fence_treemodel)
-    self.fence_treeview.set_headers_visible(FALSE)
+    self.fence_treeview.set_headers_visible(False)
 
     selection = self.fence_treeview.get_selection()
     selection.connect('changed',self.on_fence_tree_changed)
@@ -365,10 +374,6 @@ class ConfigTabController:
     #set fence daemon fields
     self.post_join.set_text(fptr.getPostJoinDelay())
     self.post_fail.set_text(fptr.getPostFailDelay())
-    if fptr.getCleanStart() == "0":
-      self.clean_start.set_active(FALSE)
-    else:
-      self.clean_start.set_active(TRUE)
     self.cluster_props_dlg.show()
 
   def on_cluster_props_edit_ok(self, button):
@@ -378,7 +383,6 @@ class ConfigTabController:
     version = self.config_version.get_text()
     postjoin = self.post_join.get_text()
     postfail = self.post_fail.get_text()
-    cleanstart = self.clean_start.get_active()
 
     if name == "":
       self.errorMessage(NEED_CLUSTER_NAME)
@@ -390,7 +394,7 @@ class ConfigTabController:
       self.config_version.select_region(0, -1)
       return
 
-    if version.isdigit() == FALSE: 
+    if version.isdigit() == False: 
       self.errorMessage(CONFIG_VERSION_DIGITS)
       self.config_version.set_text(cptr.getConfigVersion())
       self.config_version.select_region(0, -1)
@@ -404,21 +408,21 @@ class ConfigTabController:
       return
 
 
-    if postjoin.startswith("-") == TRUE:
+    if postjoin.startswith("-") == True:
       postjoinstr = postjoin[1:]
     else:
       postjoinstr = postjoin
-    if postjoinstr.isdigit() == FALSE:
+    if postjoinstr.isdigit() == False:
       if postjoin.strip() != "":
         self.errorMessage(NEED_VALID_POSTJOIN)
         self.post_join.select_region(0, -1)
         return
 
-    if postfail.startswith("-") == TRUE:
+    if postfail.startswith("-") == True:
       postfailstr = postfail[1:]
     else:
       postfailstr = postfail
-    if postfailstr.isdigit() == FALSE:
+    if postfailstr.isdigit() == False:
       if postfail.strip() != "":
         self.errorMessage(NEED_VALID_POSTFAIL)
         self.post_fail.select_region(0, -1)
@@ -441,10 +445,6 @@ class ConfigTabController:
     else:
       fdptr.addAttribute("post_fail_delay",POST_FAIL_DEFAULT)
 
-    if cleanstart == FALSE:
-      fdptr.addAttribute("clean_start","0")
-    else:
-      fdptr.addAttribute("clean_start","1")
 
     self.model_builder.setModified()
     args = list()
@@ -492,27 +492,21 @@ class ConfigTabController:
                              FENCE_TYPE_COL, F_NODE_TYPE,
                              FENCE_OBJ_COL, nd)
 
-    self.fence_panel_label.set_use_markup(TRUE)
+    self.fence_panel_label.set_use_markup(True)
     self.fence_panel_label.set_markup(FENCE_PANEL_LABEL % nd.getName())
-    fence_placeholder = nd.getChildren()
-    if len(fence_placeholder) == 0:
-      fens = Fence()
-      nd.addChild(fens)
-    kids = fence_placeholder[0].getChildren()
-    #kids holds a list of fence levels
-    for kid in kids:
+    for fence_level in nd.getFenceLevels():
       flevel_iter = treemodel.append(node_iter)
       flevel_substr = FENCE_LEVEL % level_index
       ##The next line mutates the incoming obj tree to issue sensible 
       ##level names
-      kid.addAttribute("name",str(level_index))
+      fence_level.addAttribute("name",str(level_index))
       level_index = level_index + 1
       flevel_str = "<span size=\"11000\"><b>" + flevel_substr + "</b></span>"
       treemodel.set(flevel_iter, FENCE_NAME_COL, flevel_str,
                                  FENCE_TYPE_COL, F_LEVEL_TYPE,
-                                 FENCE_OBJ_COL, kid )
+                                 FENCE_OBJ_COL, fence_level )
 
-      fences = kid.getChildren()
+      fences = fence_level.getChildren()
       for fence in fences:
         fence_iter = treemodel.append(flevel_iter)
         fence_str = "<span size=\"11000\"><b>" + fence.getName() + "</b></span>"
@@ -564,6 +558,9 @@ class ConfigTabController:
     self.fi_panel.hide()
 
   def on_create_fi(self, button):
+    if len(self.model_builder.getFenceDevices()) == 0:
+      MessageLibrary.errorMessage(_("No configured Fence Devices available.\nConfigure Fence Device first."))
+      return
     selection = self.fence_treeview.get_selection()
     model,iter = selection.get_selected()
     if iter == None:
@@ -653,20 +650,18 @@ class ConfigTabController:
     selection = self.fence_treeview.get_selection()
     model,iter = selection.get_selected()
     root_iter = model.get_iter_root()
-    obj = model.get_value(root_iter, FENCE_OBJ_COL) #node
-    fence_ptr = obj.getChildren()[0]
+    nd = model.get_value(root_iter, FENCE_OBJ_COL) #node
     #find out how many levels
-    kin = fence_ptr.getChildren()
-    num_kin = len(kin)
-    if num_kin > 0:
-      attr_val = num_kin + 1
+    num_levels = len(nd.getFenceLevels())
+    if num_levels > 0:
+      attr_val = num_levels + 1
     else:
       attr_val = 1
     method = Method()
     method.addAttribute("name",str(attr_val))
-    fence_ptr.addChild(method)
+    nd.getFence().addChild(method)
     self.model_builder.setModified()
-    self.prep_fence_panel(obj)
+    self.prep_fence_panel(nd)
 
   def on_del_level(self, button):
     selection = self.fence_treeview.get_selection()
@@ -684,7 +679,7 @@ class ConfigTabController:
       return
     root_iter = model.get_iter_root()
     nd = model.get_value(root_iter, FENCE_OBJ_COL)
-    fence_ptr = nd.getChildren()[0]
+    fence_ptr = nd.getFence()
     fence_ptr.removeChild(obj)
     self.model_builder.setModified()
     self.prep_fence_panel(nd)
@@ -729,7 +724,7 @@ class ConfigTabController:
 
     self.fi_options.set_menu(menu) 
 
-  def refresh_fi_panel(self, editmode=TRUE):
+  def refresh_fi_panel(self, editmode=True):
     #1) Load option menu by getting list of current fence devices and
     #   building menu's by setting menu labels to 
     #   <Generic Fence Name> + (name used in fence device table)
@@ -804,15 +799,15 @@ class ConfigTabController:
     self.node_props_flag = NODE_NEW
     self.node_props_name.set_text("")
     self.node_props_name.grab_focus()
-    self.node_props_name.set_activates_default(gtk.TRUE)
+    self.node_props_name.set_activates_default(True)
     self.node_props_votes.set_text("")
     if self.model_builder.getLockType() == GULM_TYPE:
       self.gulm_lockserver.show()
-      self.gulm_lockserver.set_active(FALSE)
+      self.gulm_lockserver.set_active(False)
       self.mcast_interface.hide()
     else:
       self.gulm_lockserver.hide()
-      if self.model_builder.isMulticast() == TRUE:
+      if self.model_builder.isMulticast() == True:
         self.mcast_interface.show()
       else:
         self.mcast_interface.hide()
@@ -827,7 +822,7 @@ class ConfigTabController:
     if votesattr == "":
       votesattr = "1"
 
-    if votesattr.isdigit() == FALSE:
+    if votesattr.isdigit() == False:
       self.errorMessage(VOTES_ONLY_DIGITS)
       self.node_props_votes.set_text("")
       return
@@ -860,22 +855,31 @@ class ConfigTabController:
       nds = self.model_builder.getNodes()
       for n in nds:
         if n.getName() == nameattr:
+          self.node_props_name.select_region(0, (-1))
+          self.node_props_name.grab_focus()
           self.errorMessage(NODE_UNIQUE_NAME)
-          self.node_props_name.set_text("")
           return 
-
+      # node's name may not be equal to fencedevice's name
+      fds = self.model_builder.getFenceDevices()
+      for fd in fds:
+        if fd.getName() == nameattr:
+          self.node_props_name.select_region(0, (-1))
+          self.node_props_name.grab_focus()
+          self.errorMessage(NODE_NAME_EQUAL_TO_FD_NAME % nameattr)
+          return
+      
       cn = ClusterNode()
       cn.addAttribute(NAME_ATTR,nameattr)
       cn.addAttribute(VOTES_ATTR,votesattr)
       self.model_builder.addNode(cn)
 
       if self.model_builder.getLockType() == GULM_TYPE:
-        if self.gulm_lockserver.get_active() == TRUE:
+        if self.gulm_lockserver.get_active() == True:
           ls = Lockserver()
           ls.addAttribute(NAME_ATTR,nameattr)
           self.model_builder.getGULMPtr().addChild(ls)
       else:  #DLM Type locking...
-        if self.model_builder.isMulticast() == TRUE:
+        if self.model_builder.isMulticast() == True:
           mcast = cn.getMulticastNode()
           if mcast != None:
             mcast.addAttribute("addr",self.model_builder.getMcastAddr())
@@ -895,11 +899,20 @@ class ConfigTabController:
         nds = self.model_builder.getNodes()
         for n in nds:
           if n.getName() == nameattr:
+            #self.node_props_name.set_text("ndname")
+            self.node_props_name.select_region(0, (-1))
+            self.node_props_name.grab_focus()
             self.errorMessage(NODE_UNIQUE_NAME)
-            self.node_props_name.set_text("ndname")
-            return 
+            return
+        # node's name may not be equal to fencedevice's name
+        for fd in self.model_builder.getFenceDevices():
+          if fd.getName() == nameattr:
+            self.node_props_name.select_region(0, (-1))
+            self.node_props_name.grab_focus()
+            self.errorMessage(NODE_NAME_EQUAL_TO_FD_NAME % nameattr)
+            return
         if self.model_builder.getLockType() == GULM_TYPE:
-          if islockserver and (self.gulm_lockserver.get_active() == TRUE):
+          if islockserver and (self.gulm_lockserver.get_active() == True):
             lsn = self.model_builder.getLockServer(ndname)
             lsn.addAttribute(NAME_ATTR,nameattr)
         nd.addAttribute(NAME_ATTR,nameattr)
@@ -909,17 +922,17 @@ class ConfigTabController:
       nd.addAttribute(VOTES_ATTR,votesattr) 
 
       if self.model_builder.getLockType() == GULM_TYPE:
-        if islockserver and (self.gulm_lockserver.get_active() == FALSE):
+        if islockserver and (self.gulm_lockserver.get_active() == False):
           gptr = self.model_builder.getGULMPtr()
           gptr.removeChild(self.model_builder.getLockServer(nd.getName()))
-        elif (islockserver == FALSE) and (self.gulm_lockserver.get_active() == TRUE):
+        elif (islockserver == False) and (self.gulm_lockserver.get_active() == True):
           ls = Lockserver()
           ls.addAttribute(NAME_ATTR,nameattr)
           gptr = self.model_builder.getGULMPtr()
           gptr.addChild(ls)
 
       else:
-        if self.model_builder.isMulticast() == TRUE:
+        if self.model_builder.isMulticast() == True:
           ifc = self.mcast_interface_entry.get_text().strip()
           if ifc == "":
             nd.setInterface("eth0") #set the default
@@ -941,7 +954,7 @@ class ConfigTabController:
 
   def on_clusternode_edit_b(self, button):
     self.node_props_flag = NODE_EXISTING
-    self.node_props_votes.set_activates_default(gtk.TRUE)
+    self.node_props_votes.set_activates_default(True)
     self.prep_clusternode_edit_dialog(NODE_EXISTING)
     self.node_props.set_default_response(gtk.RESPONSE_OK)
     self.node_props.run()
@@ -968,11 +981,11 @@ class ConfigTabController:
       self.node_props_votes.set_text("1")
       if self.model_builder.getLockType() == GULM_TYPE:
         self.gulm_lockserver.show()
-        self.gulm_lockserver.set_active(FALSE)
+        self.gulm_lockserver.set_active(False)
         self.mcast_interface.hide()  #Insurance...
       else:  #Uses DLM Type locking then...
         self.gulm_lockserver.hide()
-        if self.model_builder.isMulticast() == TRUE:
+        if self.model_builder.isMulticast() == True:
           self.mcast_interface.show()
         else: 
           self.mcast_interface.hide()
@@ -997,12 +1010,12 @@ class ConfigTabController:
         self.gulm_lockserver.show()
         self.mcast_interface.hide()
         if self.model_builder.isNodeLockserver(attrs[NAME_ATTR]):
-          self.gulm_lockserver.set_active(TRUE)
+          self.gulm_lockserver.set_active(True)
         else:
-          self.gulm_lockserver.set_active(FALSE)
+          self.gulm_lockserver.set_active(False)
       else:  #DLM type then...
         self.gulm_lockserver.hide()
-        if self.model_builder.isMulticast() == TRUE:
+        if self.model_builder.isMulticast() == True:
           self.mcast_interface.show()
           ifc = nd.getInterface()
           if ifc != None:
@@ -1089,7 +1102,9 @@ class ConfigTabController:
                                 2, fd_name)
 
       self.fd_delete_treeview.get_selection().unselect_all()
-
+      
+      self.fd_delete.set_title(FD_DELETION_WARNING)
+      self.fd_delete_treeview.get_column(0).set_title(AFFECTED_CLUSTER_NODES)
       if num_kees == 1:
         self.fd_delete_warning1.set_text(WARNING1 % fd_name)
         self.fd_delete_warning2.set_text(WARNING2)
@@ -1097,40 +1112,24 @@ class ConfigTabController:
         self.fd_delete_warning1.set_text(WARNINGS1 % fd_name)
         self.fd_delete_warning2.set_text(WARNINGS2)
 
-      self.fd_delete.show()
-
-  def on_fd_delete_ok(self, button):
-    selection = self.treeview.get_selection()
-    outer_model,outer_iter = selection.get_selected()
-    obj = outer_model.get_value(outer_iter, OBJ_COL)
-    fd_ptr = self.model_builder.getFenceDevicePtr()
-    fd_ptr.removeChild(obj)
-    model = self.fd_delete_treeview.get_model()
-    model.foreach(self.remove_fence_from_node, None)
-    self.fd_delete.hide()
-    self.model_builder.setModified()
-    args = list()
-    args.append(FENCE_DEVICES_TYPE)
-    apply(self.reset_tree_model, args)
-
-  def remove_fence_from_node(self, model,path,iter, *args):
-    node = model.get_value(iter, 1)
-    fd_name = model.get_value(iter, 2)
-    got_one = 1
-    while got_one > 0:
-      got_one = 0
-      flevels = node.getFenceLevels()
-      for flevel in flevels:
-        kids = flevel.getChildren()
-        for kid in kids:
-          if kid.getName().strip() == fd_name.strip():
-            flevel.removeChild(kid)
-            got_one = 1
-      
-  def on_fd_delete_cancel(self, button):
-    self.fd_delete.hide()
-      
-
+      response = self.fd_delete.run()
+      self.fd_delete.hide()
+      if response == gtk.RESPONSE_YES:
+        fd_ptr = self.model_builder.getFenceDevicePtr()
+        fd_ptr.removeChild(obj)
+        
+        # update nodes' fences
+        for node in kees:
+          for fence_level in node.getFenceLevels():
+            for fence in fence_level.getChildren()[:]:
+              if fence.getName().strip() == obj.getName().strip():
+                fence_level.removeChild(fence)
+        
+        self.model_builder.setModified()
+        args = list()
+        args.append(FENCE_DEVICES_TYPE)
+        apply(self.reset_tree_model, args)
+  
   def on_fd_panel_cancel(self, button):
     self.fd_panel.hide()
     self.fence_handler.clear_fd_forms()
@@ -1236,13 +1235,48 @@ class ConfigTabController:
   def on_faildom_delete(self, button):
     selection = self.treeview.get_selection()
     model,iter = selection.get_selected()
-    obj = model.get_value(iter, OBJ_COL)
-    retval = self.warningMessage(CONFIRM_FAILDOM_REMOVE % obj.getName())
-    if (retval == gtk.RESPONSE_NO):
-      return
+    faildom = model.get_value(iter, OBJ_COL)
+    
+    # find affected services
+    services = []
+    for service in self.model_builder.getServices():
+      domain = service.getAttribute('domain')
+      if domain == faildom.getName():
+        services.append(service)
+    
+    # prompt
+    if len(services) == 0:  #simple warning...
+      retval = self.warningMessage(CONFIRM_FAILDOM_REMOVE % faildom.getName())
+      if retval != gtk.RESPONSE_YES:
+        return
+    else:
+      treemodel = self.fd_delete_treeview.get_model()
+      treemodel.clear()
+      for service in services:
+        new_iter = treemodel.append()
+        treemodel.set(new_iter, 0, service.getName())
+      self.fd_delete_treeview.get_selection().unselect_all()
+      self.fd_delete.set_title(FAILDOM_DELETION_WARNING)
+      self.fd_delete_treeview.get_column(0).set_title(AFFECTED_SERVICES)
+      if len(services) == 1:
+        self.fd_delete_warning1.set_text(WARNING3 % faildom.getName())
+        self.fd_delete_warning2.set_text(WARNING4)
+      else:
+        self.fd_delete_warning1.set_text(WARNINGS3 % faildom.getName())
+        self.fd_delete_warning2.set_text(WARNINGS4)
+      response = self.fd_delete.run()
+      self.fd_delete.hide()
+      if response != gtk.RESPONSE_YES:
+        return
+    
+    # remove failover domain
     ###XXX-FIX should be wrapped in exception handler
     faildoms_ptr = self.model_builder.getFailoverDomainPtr()
-    faildoms_ptr.removeChild(obj)
+    faildoms_ptr.removeChild(faildom)
+    # update services
+    for service in services:
+      service.removeAttribute('domain')
+    
     self.model_builder.setModified()
     args = list()
     args.append(FAILOVER_DOMAINS_TYPE)
@@ -1304,18 +1338,57 @@ class ConfigTabController:
   def on_rc_delete(self, button):
     selection = self.treeview.get_selection()
     model,iter = selection.get_selected()
-    obj = model.get_value(iter, OBJ_COL)
-    retval = self.warningMessage(CONFIRM_RC_REMOVE % obj.getName())
-    if (retval == gtk.RESPONSE_NO):
-      return
-    rc_ptr = self.model_builder.getResourcesPtr()
-    self.model_builder.removeReferences(obj)
-    rc_ptr.removeChild(obj)
+    rc = model.get_value(iter, OBJ_COL)
+    
+    # find affected services
+    services = []
+    for service in self.model_builder.getServices():
+      if self.__on_rc_delete_recurse(rc, service):
+        services.append(service)
+    
+    # prompt
+    if len(services) == 0:  #simple warning...
+      retval = self.warningMessage(CONFIRM_RC_REMOVE % rc.getName())
+      if retval != gtk.RESPONSE_YES:
+        return
+    else:
+      treemodel = self.fd_delete_treeview.get_model()
+      treemodel.clear()
+      for service in services:
+        new_iter = treemodel.append()
+        treemodel.set(new_iter, 0, service.getName())
+      self.fd_delete_treeview.get_selection().unselect_all()
+      self.fd_delete.set_title(RESOURCE_DELETION_WARNING)
+      self.fd_delete_treeview.get_column(0).set_title(AFFECTED_SERVICES)
+      if len(services) == 1:
+        self.fd_delete_warning1.set_text(WARNING5 % rc.getName())
+        self.fd_delete_warning2.set_text(WARNING6)
+      else:
+        self.fd_delete_warning1.set_text(WARNINGS5 % rc.getName())
+        self.fd_delete_warning2.set_text(WARNINGS6)
+      response = self.fd_delete.run()
+      self.fd_delete.hide()
+      if response != gtk.RESPONSE_YES:
+        return
+    
+    # remove
+    self.model_builder.removeReferences(rc)
+    rcs_ptr = self.model_builder.getResourcesPtr()
+    rcs_ptr.removeChild(rc)
     self.model_builder.setModified()
+    
     args = list()
     args.append(RESOURCES_TYPE)
     apply(self.reset_tree_model, args)
-
+  def __on_rc_delete_recurse(self, tagobj, level):
+    for t in level.getChildren():
+      if t.isRefObject():
+        if t.getObj() == tagobj:
+          return True
+      if self.__on_rc_delete_recurse(tagobj, t):
+        return True
+    return False
+  
   def rc_panel_ok(self, button):
     #first, find out if this is for edited props, or a new device
     selection = self.treeview.get_selection()
@@ -1378,7 +1451,8 @@ class ConfigTabController:
 
     #Made it past unique name check -- ready to add service
     service = Service()
-    service.addAttribute("name",svc_name)
+    service.addAttribute("name", svc_name)
+    service.addAttribute("autostart", "1") #Have autostart set by default
     rm_ptr = self.model_builder.getResourceManagerPtr()
     rm_ptr.addChild(service)
     self.svc_add_dlg.hide()
@@ -1476,45 +1550,40 @@ class ConfigTabController:
                                                                                 
   def node_props_delete(self, *args):
     self.node_props.hide()
-    return gtk.TRUE
+    return True
 
   def cluster_props_dlg_delete(self, *args):
     self.cluster_props_dlg.hide()
-    return gtk.TRUE
+    return True
 
   def fence_panel_delete(self, *args):
     self.fence_panel.hide()
-    return gtk.TRUE
+    return True
 
   def fd_panel_delete(self, *args):
     self.fd_panel.hide()
-    return gtk.TRUE
+    return True
 
   def fi_panel_delete(self, *args):
     self.fi_panel.hide()
-    return gtk.TRUE
+    return True
 
   def faildom_panel_delete(self, *args):
     self.faildom_panel.hide()
-    return gtk.TRUE
+    return True
 
   def add_faildom_dlg_delete(self, *args):
     self.add_faildom_dlg.hide()
-    return gtk.TRUE
+    return True
 
   def rc_panel_delete(self, *args):
     self.rc_panel.hide()
-    return gtk.TRUE
+    return True
 
   def on_svc_mgmt_delete(self, *args):
     self.service_controller_close()
-    return gtk.TRUE
+    return True
 
   def on_svc_add_delete(self, *args):
     self.svc_add_dlg.hide()
-    return gtk.TRUE
-
-  def fd_delete_delete(self, *args):
-    self.fd_delete.hide()
-    return gtk.TRUE
-
+    return True
