@@ -1,7 +1,6 @@
 import os
 import gtk
 import gtk.glade
-from gtk import TRUE, FALSE
 from ValidationError import ValidationError
 import MessageLibrary
 import ModelBuilder
@@ -9,9 +8,10 @@ import ModelBuilder
 INSTALLDIR="/usr/share/system-config-cluster"
 
 FD_PROVIDE_NAME = _("A unique name must be provided for each Fence Device")
+FD_NAME_EQUAL_TO_NODE_NAME = _("There is a Cluster Node named \"%s\". Fence Devices cannot have the same names as Cluster Nodes. Please choose another name for this Fence Device.")
 
 FD_PROVIDE_PATH = _("An xCAT path must be provided for each xCAT Fence Device")
-FD_PROVIDE_SERVER = _("A server address must be provided for this Fence Device")
+FD_PROVIDE_SERVERS = _("Servers' names or addresses, separated by whitespaces, must be provided for this Fence Device")
 FD_PROVIDE_CSERVER = _("A cserver address must be provided for this Egenera Fence Device")
 FD_PROVIDE_IP = _("An IP address must be provided for this Fence Device")
 FD_PROVIDE_LOGIN = _("A login name must be provided for this Fence Device")
@@ -52,6 +52,7 @@ FENCE_OPTS = {"fence_apc":_("APC Power Device"),
               "fence_mcdata":_("McDATA SAN Switch"),
               "fence_egenera":_("Egenera SAN Controller"),
               "fence_bullpap":_("Bull PAP"),
+              "fence_drac":_("DRAC"),
               "fence_ipmilan":_("IPMI Lan"),
               "fence_manual":_("Manual Fencing") }
 
@@ -59,7 +60,7 @@ FENCE_FD_ATTRS = {"fence_apc":["name","ipaddr","login","passwd"],
               "fence_wti":["name","ipaddr","passwd"],
               "fence_brocade":["name","ipaddr","login","passwd"],
               "fence_vixel":["name","ipaddr","passwd"],
-              "fence_gnbd":["name","server"],
+              "fence_gnbd":["name","servers"],
               "fence_ilo":["name","hostname","login","passwd"],
               "fence_sanbox2":["name","ipaddr","login","passwd"],
               "fence_bladecenter":["name","ipaddr","login","passwd"],
@@ -67,13 +68,14 @@ FENCE_FD_ATTRS = {"fence_apc":["name","ipaddr","login","passwd"],
               "fence_egenera":["name","cserver"],
               "fence_ipmilan":["name","ipaddr","login","passwd"],
               "fence_bullpap":["name","ipaddr","login","passwd"],
+              "fence_drac":["name","ipaddr","login","passwd"],
               "fence_manual":["name"] }
 
 FENCE_FI_ATTRS = {"fence_apc":["port","switch"],
               "fence_wti":["port"],
               "fence_brocade":["port"],
               "fence_vixel":["port"],
-              "fence_gnbd":["ipaddress"],
+              "fence_gnbd":[],
               "fence_ilo":[],
               "fence_sanbox2":["port"],
               "fence_bladecenter":["blade"],
@@ -81,6 +83,7 @@ FENCE_FI_ATTRS = {"fence_apc":["port","switch"],
               "fence_egenera":["lpan","pserver"],
               "fence_ipmilan":[],
               "fence_bullpap":["domain"],
+              "fence_drac":[],
               "fence_manual":[] }
 
 PRETTY_NAME_ATTRS = {"port":_("Port"),
@@ -94,6 +97,7 @@ PRETTY_NAME_ATTRS = {"port":_("Port"),
                      "passwd":_("Password"),
                      "name":_("Name"),
                      "server":_("Server"),
+                     "servers":_("Servers"),
                      "domain":_("Domain"),
                      "hostname":_("Hostname"),
                      "path":_("Path"),
@@ -154,6 +158,7 @@ class FenceHandler:
               "fence_vixel":self.pop_vixel,
               "fence_gnbd":self.pop_gnbd,
               "fence_ilo":self.pop_ilo,
+              "fence_drac":self.pop_drac,
               "fence_sanbox2":self.pop_sanbox2,
               "fence_bladecenter":self.pop_bladecenter,
               "fence_mcdata":self.pop_mcdata,
@@ -168,6 +173,7 @@ class FenceHandler:
               "fence_vixel":self.pop_vixel_fd,
               "fence_gnbd":self.pop_gnbd_fd,
               "fence_ilo":self.pop_ilo_fd,
+              "fence_drac":self.pop_drac_fd,
               "fence_sanbox2":self.pop_sanbox2_fd,
               "fence_bladecenter":self.pop_bladecenter_fd,
               "fence_mcdata":self.pop_mcdata_fd,
@@ -182,6 +188,7 @@ class FenceHandler:
               "fence_vixel":self.val_vixel,
               "fence_gnbd":self.val_gnbd,
               "fence_ilo":self.val_ilo,
+              "fence_drac":self.val_drac,
               "fence_sanbox2":self.val_sanbox2,
               "fence_bladecenter":self.val_bladecenter,
               "fence_mcdata":self.val_mcdata,
@@ -196,6 +203,7 @@ class FenceHandler:
               "fence_vixel":self.val_vixel_fd,
               "fence_gnbd":self.val_gnbd_fd,
               "fence_ilo":self.val_ilo_fd,
+              "fence_drac":self.val_drac_fd,
               "fence_sanbox2":self.val_sanbox2_fd,
               "fence_bladecenter":self.val_bladecenter_fd,
               "fence_mcdata":self.val_mcdata_fd,
@@ -231,6 +239,9 @@ class FenceHandler:
   def pop_ilo(self, attrs):
     pass
  
+  def pop_drac(self, attrs):
+    pass
+ 
   def pop_vixel(self, attrs):
     self.vixel_port_text(attrs["port"])
  
@@ -241,7 +252,7 @@ class FenceHandler:
     pass
  
   def pop_gnbd(self, attrs):
-    self.gnbd_ip.set_text(attrs["ipaddress"])
+    pass
  
   def pop_egenera(self, attrs):
     self.egenera_lpan.set_text(attrs["lpan"])
@@ -265,7 +276,6 @@ class FenceHandler:
     self.wti_port.set_text("") 
     self.brocade_port.set_text("")
     self.vixel_port.set_text("")
-    self.gnbd_ip.set_text("") 
     self.sanbox2_port.set_text("")
     self.bladecenter_blade.set_text("")
     self.mcdata_port.set_text("")
@@ -290,6 +300,10 @@ class FenceHandler:
     self.ilo_fd_login.set_text("")
     self.ilo_fd_passwd.set_text("")
     self.ilo_fd_hostname.set_text("")
+    self.drac_fd_name.set_text("")
+    self.drac_fd_login.set_text("")
+    self.drac_fd_passwd.set_text("")
+    self.drac_fd_ip.set_text("")
     self.vixel_fd_name.set_text("")
     self.vixel_fd_ip.set_text("")
     self.vixel_fd_passwd.set_text("")
@@ -299,7 +313,7 @@ class FenceHandler:
     self.mcdata_fd_login.set_text("")
     self.mcdata_fd_passwd.set_text("")
     self.gnbd_fd_name.set_text("")
-    self.gnbd_fd_server.set_text("")
+    self.gnbd_fd_servers.set_text("")
     self.egenera_fd_name.set_text("")
     self.egenera_fd_cserver.set_text("")
     self.sanbox2_fd_name.set_text("")
@@ -345,6 +359,12 @@ class FenceHandler:
     self.ilo_fd_passwd.set_text(attrs["passwd"])
     self.ilo_fd_hostname.set_text(attrs["hostname"])
 
+  def pop_drac_fd(self, attrs):
+    self.drac_fd_name.set_text(attrs["name"])
+    self.drac_fd_login.set_text(attrs["login"])
+    self.drac_fd_passwd.set_text(attrs["passwd"])
+    self.drac_fd_ip.set_text(attrs["ipaddr"])
+
  
   def pop_vixel_fd(self, attrs):
     self.vixel_fd_name.set_text(attrs["name"])
@@ -364,7 +384,7 @@ class FenceHandler:
  
   def pop_gnbd_fd(self, attrs):
     self.gnbd_fd_name.set_text(attrs["name"])
-    self.gnbd_fd_server.set_text(attrs["server"])
+    self.gnbd_fd_servers.set_text(attrs["servers"])
 
  
   def pop_egenera_fd(self, attrs):
@@ -404,7 +424,6 @@ class FenceHandler:
     self.wti_port = self.fence_xml.get_widget('entry3') 
     self.brocade_port = self.fence_xml.get_widget('entry4') 
     self.vixel_port = self.fence_xml.get_widget('entry5') 
-    self.gnbd_ip = self.fence_xml.get_widget('entry6') 
     self.ilo_port = self.fence_xml.get_widget('entry7') 
     self.sanbox2_port = self.fence_xml.get_widget('entry8') 
     self.bladecenter_blade = self.fence_xml.get_widget('entry41') 
@@ -433,13 +452,18 @@ class FenceHandler:
     self.vixel_fd_passwd = self.fence_xml.get_widget('entry25')
 
     self.gnbd_fd_name = self.fence_xml.get_widget('entry26')
-    self.gnbd_fd_server = self.fence_xml.get_widget('entry27')
+    self.gnbd_fd_servers = self.fence_xml.get_widget('entry27')
 
     self.ilo_fd_name = self.fence_xml.get_widget('entry28')
     self.ilo_fd_login = self.fence_xml.get_widget('entry29')
     self.ilo_fd_passwd = self.fence_xml.get_widget('entry30')
     self.ilo_fd_hostname = self.fence_xml.get_widget('entry31')
 
+    self.drac_fd_name = self.fence_xml.get_widget('entry57')
+    self.drac_fd_login = self.fence_xml.get_widget('entry59')
+    self.drac_fd_passwd = self.fence_xml.get_widget('entry60')
+    self.drac_fd_ip = self.fence_xml.get_widget('entry58')
+
     self.sanbox2_fd_name = self.fence_xml.get_widget('entry32')
     self.sanbox2_fd_ip = self.fence_xml.get_widget('entry33')
     self.sanbox2_fd_login = self.fence_xml.get_widget('entry46')
@@ -484,15 +508,15 @@ class FenceHandler:
 
     
   def val_apc_fd(self, name):
-    rectify_fence_name = FALSE
+    rectify_fence_name = False
     if self.apc_fd_name.get_text() == "":
       raise ValidationError('FATAL', FD_PROVIDE_NAME)
     self.validateNCName(self.apc_fd_name)
     if name != self.apc_fd_name.get_text():
       res = self.check_unique_fd_name(self.apc_fd_name.get_text())
-      if res == FALSE:  #name is already used
+      if res == False:  #name is already used
         raise ValidationError('FATAL', FD_PROVIDE_NAME)
-      rectify_fence_name = TRUE
+      rectify_fence_name = True
     
     if self.apc_fd_ip.get_text() == "":
         raise ValidationError('FATAL', FD_PROVIDE_IP)
@@ -501,7 +525,7 @@ class FenceHandler:
     if self.apc_fd_passwd.get_text() == "":
         raise ValidationError('FATAL', FD_PROVIDE_PASSWD)
 
-    if rectify_fence_name == TRUE:
+    if rectify_fence_name == True:
       self.model_builder.rectifyNewFencedevicenameWithFences(name,self.apc_fd_name.get_text())
 
     fields = {}
@@ -514,22 +538,22 @@ class FenceHandler:
  
  
   def val_wti_fd(self, name):
-    rectify_fence_name = FALSE
+    rectify_fence_name = False
     if self.wti_fd_name.get_text() == "":
       raise ValidationError('FATAL', FD_PROVIDE_NAME)
     self.validateNCName(self.wti_fd_name)
     if name != self.wti_fd_name.get_text():
       res = self.check_unique_fd_name(self.wti_fd_name.get_text())
-      if res == FALSE:  #name is already used
+      if res == False:  #name is already used
         raise ValidationError('FATAL', FD_PROVIDE_NAME)
-      rectify_fence_name = TRUE
+      rectify_fence_name = True
 
     if self.wti_fd_ip.get_text() == "":
         raise ValidationError('FATAL', FD_PROVIDE_IP)
     if self.wti_fd_passwd.get_text() == "":
         raise ValidationError('FATAL', FD_PROVIDE_PASSWD)
 
-    if rectify_fence_name == TRUE:
+    if rectify_fence_name == True:
       self.model_builder.rectifyNewFencedevicenameWithFences(name,self.wti_fd_name.get_text())
 
     fields = {}
@@ -541,15 +565,15 @@ class FenceHandler:
  
  
   def val_brocade_fd(self, name):
-    rectify_fence_name = FALSE
+    rectify_fence_name = False
     if self.brocade_fd_name.get_text() == "":
       raise ValidationError('FATAL', FD_PROVIDE_NAME)
     self.validateNCName(self.brocade_fd_name)
     if name != self.brocade_fd_name.get_text():
       res = self.check_unique_fd_name(self.brocade_fd_name.get_text())
-      if res == FALSE:  #name is already used
+      if res == False:  #name is already used
         raise ValidationError('FATAL', FD_PROVIDE_NAME)
-      rectify_fence_name = TRUE
+      rectify_fence_name = True
 
     if self.brocade_fd_ip.get_text() == "":
         raise ValidationError('FATAL', FD_PROVIDE_IP)
@@ -558,7 +582,7 @@ class FenceHandler:
     if self.brocade_fd_passwd.get_text() == "":
         raise ValidationError('FATAL', FD_PROVIDE_PASSWD)
 
-    if rectify_fence_name == TRUE:
+    if rectify_fence_name == True:
       self.model_builder.rectifyNewFencedevicenameWithFences(name,self.brocade_fd_name.get_text())
 
     fields = {}
@@ -571,15 +595,15 @@ class FenceHandler:
  
  
   def val_ilo_fd(self, name):
-    rectify_fence_name = FALSE
+    rectify_fence_name = False
     if self.ilo_fd_name.get_text() == "":
       raise ValidationError('FATAL', FD_PROVIDE_NAME)
     self.validateNCName(self.ilo_fd_name)
     if name != self.ilo_fd_name.get_text():
       res = self.check_unique_fd_name(self.ilo_fd_name.get_text())
-      if res == FALSE:  #name is already used
+      if res == False:  #name is already used
         raise ValidationError('FATAL', FD_PROVIDE_NAME)
-      rectify_fence_name = TRUE
+      rectify_fence_name = True
 
     if self.ilo_fd_login.get_text() == "":
         raise ValidationError('FATAL', FD_PROVIDE_LOGIN)
@@ -588,7 +612,7 @@ class FenceHandler:
     if self.ilo_fd_hostname.get_text() == "":
         raise ValidationError('FATAL', FD_PROVIDE_HOSTNAME)
 
-    if rectify_fence_name == TRUE:
+    if rectify_fence_name == True:
       self.model_builder.rectifyNewFencedevicenameWithFences(name,self.ilo_fd_name.get_text())
 
     fields = {}
@@ -600,23 +624,53 @@ class FenceHandler:
     return fields
  
  
+  def val_drac_fd(self, name):
+    rectify_fence_name = False
+    if self.drac_fd_name.get_text() == "":
+      raise ValidationError('FATAL', FD_PROVIDE_NAME)
+    self.validateNCName(self.drac_fd_name)
+    if name != self.drac_fd_name.get_text():
+      res = self.check_unique_fd_name(self.drac_fd_name.get_text())
+      if res == False:  #name is already used
+        raise ValidationError('FATAL', FD_PROVIDE_NAME)
+      rectify_fence_name = True
+
+    if self.drac_fd_login.get_text() == "":
+        raise ValidationError('FATAL', FD_PROVIDE_LOGIN)
+    if self.drac_fd_passwd.get_text() == "":
+        raise ValidationError('FATAL', FD_PROVIDE_PASSWD)
+    if self.drac_fd_ip.get_text() == "":
+        raise ValidationError('FATAL', FD_PROVIDE_IP)
+
+    if rectify_fence_name == True:
+      self.model_builder.rectifyNewFencedevicenameWithFences(name,self.drac_fd_name.get_text())
+
+    fields = {}
+    fields["name"] = self.drac_fd_name.get_text()
+    fields["ipaddr"] = self.drac_fd_ip.get_text()
+    fields["login"] = self.drac_fd_login.get_text()
+    fields["passwd"] = self.drac_fd_passwd.get_text()
+
+    return fields
+ 
+ 
   def val_vixel_fd(self, name):
-    rectify_fence_name = FALSE
+    rectify_fence_name = False
     if self.vixel_fd_name.get_text() == "":
       raise ValidationError('FATAL', FD_PROVIDE_NAME)
     self.validateNCName(self.vixel_fd_name)
     if name != self.vixel_fd_name.get_text():
       res = self.check_unique_fd_name(self.vixel_fd_name.get_text())
-      if res == FALSE:  #name is already used
+      if res == False:  #name is already used
         raise ValidationError('FATAL', FD_PROVIDE_NAME)
-      rectify_fence_name = TRUE
+      rectify_fence_name = True
 
     if self.vixel_fd_ip.get_text() == "":
         raise ValidationError('FATAL', FD_PROVIDE_IP)
     if self.vixel_fd_passwd.get_text() == "":
         raise ValidationError('FATAL', FD_PROVIDE_PASSWD)
 
-    if rectify_fence_name == TRUE:
+    if rectify_fence_name == True:
       self.model_builder.rectifyNewFencedevicenameWithFences(name,self.vixel_fd_name.get_text())
 
     fields = {}
@@ -628,15 +682,15 @@ class FenceHandler:
  
  
   def val_mcdata_fd(self, name):
-    rectify_fence_name = FALSE
+    rectify_fence_name = False
     if self.mcdata_fd_name.get_text() == "":
       raise ValidationError('FATAL', FD_PROVIDE_NAME)
     self.validateNCName(self.mcdata_fd_name)
     if name != self.mcdata_fd_name.get_text():
       res = self.check_unique_fd_name(self.mcdata_fd_name.get_text())
-      if res == FALSE:  #name is already used
+      if res == False:  #name is already used
         raise ValidationError('FATAL', FD_PROVIDE_NAME)
-      rectify_fence_name = TRUE
+      rectify_fence_name = True
 
     if self.mcdata_fd_ip.get_text() == "":
         raise ValidationError('FATAL', FD_PROVIDE_IP)
@@ -645,7 +699,7 @@ class FenceHandler:
     if self.mcdata_fd_passwd.get_text() == "":
         raise ValidationError('FATAL', FD_PROVIDE_PASSWD)
 
-    if rectify_fence_name == TRUE:
+    if rectify_fence_name == True:
       self.model_builder.rectifyNewFencedevicenameWithFences(name,self.mcdata_fd_name.get_text())
 
     fields = {}
@@ -657,17 +711,18 @@ class FenceHandler:
     return fields
  
   def val_manual_fd(self, name):
-    rectify_fence_name = FALSE
+    self.validateNCName(self.manual_fd_name)
     if self.manual_fd_name.get_text() == "":
       raise ValidationError('FATAL', FD_PROVIDE_NAME)
-    self.validateNCName(self.manual_fd_name)
+    
+    rectify_fence_name = False
     if name != self.manual_fd_name.get_text():
       res = self.check_unique_fd_name(self.manual_fd_name.get_text())
-      if res == FALSE:  #name is already used
+      if res == False:  #name is already used
         raise ValidationError('FATAL', FD_PROVIDE_NAME)
-      rectify_fence_name = TRUE
+      rectify_fence_name = True
 
-    if rectify_fence_name == TRUE:
+    if rectify_fence_name == True:
       self.model_builder.rectifyNewFencedevicenameWithFences(name,self.manual_fd_name.get_text())
 
     fields = {}
@@ -676,43 +731,47 @@ class FenceHandler:
     return fields
  
   def val_gnbd_fd(self, name):
-    rectify_fence_name = FALSE
+    self.validateNCName(self.gnbd_fd_name)
     if self.gnbd_fd_name.get_text() == "":
       raise ValidationError('FATAL', FD_PROVIDE_NAME)
-    self.validateNCName(self.gnbd_fd_name)
+    
+    rectify_fence_name = False
     if name != self.gnbd_fd_name.get_text():
       res = self.check_unique_fd_name(self.gnbd_fd_name.get_text())
-      if res == FALSE:  #name is already used
+      if res == False:  #name is already used
         raise ValidationError('FATAL', FD_PROVIDE_NAME)
-      rectify_fence_name = TRUE
-
-    if self.gnbd_fd_server.get_text() == "":
-      raise ValidationError('FATAL', FD_PROVIDE_SERVER)
-
-    if rectify_fence_name == TRUE:
+      rectify_fence_name = True
+    
+    servers_new = self.gnbd_fd_servers.get_text().strip()
+    if servers_new == "":
+      raise ValidationError('FATAL', FD_PROVIDE_SERVERS)
+    for ch in ':;,':
+      if ch in servers_new:
+        raise ValidationError('FATAL', FD_PROVIDE_SERVERS)
+    
+    if rectify_fence_name == True:
       self.model_builder.rectifyNewFencedevicenameWithFences(name,self.gnbd_fd_name.get_text())
 
     fields = {}
     fields["name"] = self.gnbd_fd_name.get_text()
-    fields["server"] = self.gnbd_fd_server.get_text()
-
+    fields["servers"] = servers_new
     return fields
  
   def val_egenera_fd(self, name):
-    rectify_fence_name = FALSE
+    rectify_fence_name = False
     if self.egenera_fd_name.get_text() == "":
       raise ValidationError('FATAL', FD_PROVIDE_NAME)
     self.validateNCName(self.egenera_fd_name)
     if name != self.egenera_fd_name.get_text():
       res = self.check_unique_fd_name(self.egenera_fd_name.get_text())
-      if res == FALSE:  #name is already used
+      if res == False:  #name is already used
         raise ValidationError('FATAL', FD_PROVIDE_NAME)
-      rectify_fence_name = TRUE
+      rectify_fence_name = True
 
     if self.egenera_fd_cserver.get_text() == "":
       raise ValidationError('FATAL', FD_PROVIDE_CSERVER)
 
-    if rectify_fence_name == TRUE:
+    if rectify_fence_name == True:
       self.model_builder.rectifyNewFencedevicenameWithFences(name,self.egenera_fd_name.get_text())
 
     fields = {}
@@ -723,15 +782,15 @@ class FenceHandler:
 
  
   def val_sanbox2_fd(self, name):
-    rectify_fence_name = FALSE
+    rectify_fence_name = False
     if self.sanbox2_fd_name.get_text() == "":
       raise ValidationError('FATAL', FD_PROVIDE_NAME)
     self.validateNCName(self.sanbox2_fd_name)
     if name != self.sanbox2_fd_name.get_text():
       res = self.check_unique_fd_name(self.sanbox2_fd_name.get_text())
-      if res == FALSE:  #name is already used
+      if res == False:  #name is already used
         raise ValidationError('FATAL', FD_PROVIDE_NAME)
-      rectify_fence_name = TRUE
+      rectify_fence_name = True
 
     if self.sanbox2_fd_ip.get_text() == "":
       raise ValidationError('FATAL', FD_PROVIDE_IP)
@@ -742,7 +801,7 @@ class FenceHandler:
     if self.sanbox2_fd_passwd.get_text() == "":
       raise ValidationError('FATAL', FD_PROVIDE_PASSWD)
 
-    if rectify_fence_name == TRUE:
+    if rectify_fence_name == True:
       self.model_builder.rectifyNewFencedevicenameWithFences(name,self.sanbox2_fd_name.get_text())
 
     fields = {}
@@ -754,15 +813,15 @@ class FenceHandler:
     return fields
 
   def val_bladecenter_fd(self, name):
-    rectify_fence_name = FALSE
+    rectify_fence_name = False
     if self.bladecenter_fd_name.get_text() == "":
       raise ValidationError('FATAL', FD_PROVIDE_NAME)
     self.validateNCName(self.bladecenter_fd_name)
     if name != self.bladecenter_fd_name.get_text():
       res = self.check_unique_fd_name(self.bladecenter_fd_name.get_text())
-      if res == FALSE:  #name is already used
+      if res == False:  #name is already used
         raise ValidationError('FATAL', FD_PROVIDE_NAME)
-      rectify_fence_name = TRUE
+      rectify_fence_name = True
 
     if self.bladecenter_fd_ip.get_text() == "":
       raise ValidationError('FATAL', FD_PROVIDE_IP)
@@ -773,7 +832,7 @@ class FenceHandler:
     if self.bladecenter_fd_passwd.get_text() == "":
       raise ValidationError('FATAL', FD_PROVIDE_PASSWD)
 
-    if rectify_fence_name == TRUE:
+    if rectify_fence_name == True:
       self.model_builder.rectifyNewFencedevicenameWithFences(name,self.bladecenter_fd_name.get_text())
 
     fields = {}
@@ -785,15 +844,15 @@ class FenceHandler:
     return fields
 
   def val_ipmilan_fd(self, name):
-    rectify_fence_name = FALSE
+    rectify_fence_name = False
     if self.ipmilan_fd_name.get_text() == "":
       raise ValidationError('FATAL', FD_PROVIDE_NAME)
     self.validateNCName(self.ipmilan_fd_name)
     if name != self.ipmilan_fd_name.get_text():
       res = self.check_unique_fd_name(self.ipmilan_fd_name.get_text())
-      if res == FALSE:  #name is already used
+      if res == False:  #name is already used
         raise ValidationError('FATAL', FD_PROVIDE_NAME)
-      rectify_fence_name = TRUE
+      rectify_fence_name = True
 
     if self.ipmilan_fd_login.get_text() == "":
         raise ValidationError('FATAL', FD_PROVIDE_LOGIN)
@@ -802,7 +861,7 @@ class FenceHandler:
     if self.ipmilan_fd_ip.get_text() == "":
         raise ValidationError('FATAL', FD_PROVIDE_IP)
 
-    if rectify_fence_name == TRUE:
+    if rectify_fence_name == True:
       self.model_builder.rectifyNewFencedevicenameWithFences(name,self.ipmilan_fd_name.get_text())
 
     fields = {}
@@ -815,15 +874,15 @@ class FenceHandler:
  
  
   def val_bullpap_fd(self, name):
-    rectify_fence_name = FALSE
+    rectify_fence_name = False
     if self.bullpap_fd_name.get_text() == "":
       raise ValidationError('FATAL', FD_PROVIDE_NAME)
     self.validateNCName(self.bullpap_fd_name)
     if name != self.bullpap_fd_name.get_text():
       res = self.check_unique_fd_name(self.bullpap_fd_name.get_text())
-      if res == FALSE:  #name is already used
+      if res == False:  #name is already used
         raise ValidationError('FATAL', FD_PROVIDE_NAME)
-      rectify_fence_name = TRUE
+      rectify_fence_name = True
 
     if self.bullpap_fd_login.get_text() == "":
         raise ValidationError('FATAL', FD_PROVIDE_LOGIN)
@@ -832,7 +891,7 @@ class FenceHandler:
     if self.bullpap_fd_ip.get_text() == "":
         raise ValidationError('FATAL', FD_PROVIDE_IP)
 
-    if rectify_fence_name == TRUE:
+    if rectify_fence_name == True:
       self.model_builder.rectifyNewFencedevicenameWithFences(name,self.bullpap_fd_name.get_text())
 
     fields = {}
@@ -894,12 +953,8 @@ class FenceHandler:
     return fields
 
   def val_gnbd(self):
-    if self.gnbd_ip.get_text() == "": 
-      raise ValidationError('FATAL', FI_PROVIDE_IPADDRESS)
-
     fields = {}
-    fields["ipaddress"] = self.gnbd_ip.get_text()
-
+    fields["nodename"] = "real value will be set at ModelBuilder.perform_final_check()"
     return fields
 
   def val_ilo(self):
@@ -908,6 +963,12 @@ class FenceHandler:
 
     return fields
 
+  def val_drac(self):
+
+    fields = {}
+
+    return fields
+
   def val_sanbox2(self):
     if self.sanbox2_port.get_text() == "": 
       raise ValidationError('FATAL', FI_PROVIDE_PORT)
@@ -948,8 +1009,8 @@ class FenceHandler:
     return fields
 
   def val_manual(self): 
-
     fields = {}
+    fields["nodename"] = "real value will be set at ModelBuilder.perform_final_check()"
     return fields
 
   def val_ipmilan(self):
@@ -968,12 +1029,19 @@ class FenceHandler:
     return fields
 
   def check_unique_fd_name(self, name):
+    # check fencedevice name uniqueness
     fds = self.model_builder.getFenceDevices()
     for fd in fds:
       if fd.getName() == name:
-        return FALSE
-
-    return TRUE
+        return False
+    # fencedevice name may not be equal to cluster node name
+    nodes = self.model_builder.getNodes()
+    for node in nodes:
+      if node.getName() == name:
+        #return False
+        raise ValidationError('FATAL', FD_NAME_EQUAL_TO_NODE_NAME % name)
+    # everything OK
+    return True
 
   def getFENCE_OPTS(self):
     return FENCE_OPTS
