@@ -5,7 +5,6 @@ _ = gettext.gettext
 
 import gtk
 import gtk.glade
-from gtk import TRUE, FALSE
 import MessageLibrary
 import ModelBuilder
 from ValidationError import ValidationError
@@ -19,6 +18,8 @@ RESOURCE_PROVIDE_NAME=_("Please provide a name for this resource.")
 
 RESOURCE_PROVIDE_UNIQUE_NAME=_("Please provide a unique name for this resource.")
 
+INVALID_IP=_("Please Provide a Valid IP Address")
+
 PROVIDE_UNIQUE_IP=_("This IP Address is already declared as a resource. Please choose another.")
 
 #ADDING A NEW RESOURCE: RC form should be named the same as its tagname in
@@ -86,10 +87,10 @@ class ResourceHandler:
     addr = attrs["address"]
     self.ip.setAddrFromString(addr)
     monitor = attrs["monitor_link"]
-    if (monitor == None) or (monitor == FALSE) or (monitor == "no"):
-      self.monitor_link.set_active(FALSE)
+    if (monitor == None) or (monitor == False) or (monitor == "no"):
+      self.monitor_link.set_active(False)
     else:
-      self.monitor_link.set_active(TRUE)
+      self.monitor_link.set_active(True)
 
   def pop_script(self, attrs):
     self.script_name.set_text(attrs["name"])
@@ -98,13 +99,26 @@ class ResourceHandler:
   def pop_nfsclient(self, attrs):
     self.nfsc_name.set_text(attrs["name"])
     self.nfsc_target.set_text(attrs["target"])
-    if attrs["options"] == "rw":
-      self.nfsc_rw.set_active(TRUE)
-      self.nfsc_ro.set_active(FALSE)
+    
+    options = attrs['options'].strip().split(',')
+    if 'ro' in options:
+      self.nfsc_ro.set_active(True)
+      self.nfsc_rw.set_active(False)
     else:
-      self.nfsc_ro.set_active(TRUE)
-      self.nfsc_rw.set_active(FALSE)
-
+      self.nfsc_rw.set_active(True)
+      self.nfsc_ro.set_active(False)
+    if 'rw' in options:
+      options.remove('rw')
+    if 'ro' in options:
+      options.remove('ro')
+    
+    option_string = ''
+    if len(options) != 0:
+      option_string = options[0]
+      for opt in options[1:]:
+        option_string += ',' + opt
+    self.nfsc_options.set_text(option_string)
+      
   def pop_nfsexport(self, attrs):
     self.nfse_name.set_text(attrs["name"])
 
@@ -132,20 +146,20 @@ class ResourceHandler:
     try:
       fstype = attrs["fstype"]
       if fstype == "nfs":
-        self.netfs_fstype.set_active(TRUE)
+        self.netfs_fstype.set_active(True)
       else:
-        self.netfs_fstype.set_active(FALSE)
+        self.netfs_fstype.set_active(False)
     except KeyError, e:
-      self.netfs_fstype.set_active(TRUE)
+      self.netfs_fstype.set_active(True)
 
     try:
       force = attrs["force_unmount"]
       if force == "1" or force == "yes":
-        self.netfs_force_unmount.set_active(TRUE)
+        self.netfs_force_unmount.set_active(True)
       else:
-        self.netfs_force_unmount.set_active(FALSE)
+        self.netfs_force_unmount.set_active(False)
     except KeyError, e:
-        self.netfs_force_unmount.set_active(FALSE)
+        self.netfs_force_unmount.set_active(False)
  
     try:
       self.netfs_options.set_text(attrs["options"])
@@ -168,8 +182,16 @@ class ResourceHandler:
       self.gfs_device.set_text(attrs["device"])
     except KeyError, e:
       self.gfs_host.set_text("")
-
-
+    
+    try:
+      force = attrs["force_unmount"]
+      if force == "1" or force == "yes":
+        self.gfs_force_unmount.set_active(True)
+      else:
+        self.gfs_force_unmount.set_active(False)
+    except KeyError, e:
+      self.gfs_force_unmount.set_active(False)
+    
     try:
       self.gfs_options.set_text(attrs["options"])
     except KeyError, e:
@@ -179,22 +201,35 @@ class ResourceHandler:
     self.fs_name.set_text(attrs["name"])
     self.fs_mnt.set_text(attrs["mountpoint"])
     self.fs_device.set_text(attrs["device"])
-   
+    
     type = attrs["fstype"] 
-    y = (-1)
-    menu = self.fs_optionmenu.get_menu()
-    for item in menu.get_children():
-      y = y + 1
-      children = item.get_children()
-      if children:
-        if item.get_children()[0].get_text() == type:
-          break
-    self.fs_optionmenu.set_history(y) 
-
+    model = self.fs_combo.get_model()
+    iter = model.get_iter_first()
+    while iter != None:
+      if model.get_value(iter, 0) == type:
+        self.fs_combo.set_active_iter(iter)
+        break
+      iter = model.iter_next(iter)
+    
+    try:
+      force = attrs["force_unmount"]
+      if force == "1" or force == "yes":
+        self.fs_force_unmount.set_active(True)
+      else:
+        self.fs_force_unmount.set_active(False)
+    except KeyError, e:
+      self.fs_force_unmount.set_active(False)
+    
+    try:
+      self.fs_options.set_text(attrs["options"])
+    except KeyError, e:
+      self.fs_options.set_text("")
+    
+  
   def clear_rc_forms(self):
 
     self.ip.clear()
-    self.monitor_link.set_active(TRUE)
+    self.monitor_link.set_active(True)
 
     self.script_name.set_text("")
     self.script_filepath.set_text("")
@@ -203,23 +238,28 @@ class ResourceHandler:
 
     self.nfsc_name.set_text("")
     self.nfsc_target.set_text("")
-    self.nfsc_rw.set_active(TRUE)
+    self.nfsc_options.set_text("")
+    self.nfsc_rw.set_active(True)
 
     self.fs_name.set_text("")
     self.fs_mnt.set_text("")
     self.fs_device.set_text("")
-
+    self.fs_combo.set_active_iter(self.fs_combo.get_model().get_iter_first())
+    self.fs_force_unmount.set_active(False)
+    self.fs_options.set_text('')
+    
     self.netfs_name.set_text("")
     self.netfs_mnt.set_text("")
     self.netfs_host.set_text("")
     self.netfs_export.set_text("")
     self.netfs_options.set_text("")
-    self.netfs_force_unmount.set_active(FALSE)
-    self.netfs_fstype.set_active(TRUE)
+    self.netfs_force_unmount.set_active(False)
+    self.netfs_fstype.set_active(True)
 
     self.gfs_name.set_text("")
     self.gfs_mnt.set_text("")
     self.gfs_device.set_text("")
+    self.gfs_force_unmount.set_active(False)
     self.gfs_options.set_text("")
 
 
@@ -236,17 +276,21 @@ class ResourceHandler:
     return returnlist 
 
   def val_ip(self, *argname):
+    if self.ip.isValid() != True:
+      MessageLibrary.errorMessage(INVALID_IP)
+      return None
+    
     inaddr = argname[0]
     addr = self.ip.getAddrAsString()
     if inaddr == None: #New resource...
       res = self.check_unique_ip(addr)
-      if res == FALSE:  #adress already used
+      if res == False:  #adress already used
         raise ValidationError('FATAL',PROVIDE_UNIQUE_IP)
       
     else:
       if inaddr != addr:
         res = self.check_unique_ip(addr)
-        if res == FALSE:  #address already used
+        if res == False:  #address already used
           raise ValidationError('FATAL',PROVIDE_UNIQUE_IP)
 
     monitor = self.monitor_link.get_active()
@@ -276,13 +320,13 @@ class ResourceHandler:
 
     if name == None: #New resource...
       res = self.check_unique_script_name(script_name)
-      if res == FALSE:  #name already used for a script
+      if res == False:  #name already used for a script
         raise ValidationError('FATAL',RESOURCE_PROVIDE_UNIQUE_NAME)
       
     else:
       if name != script_name:
         res = self.check_unique_script_name(script_name)
-        if res == FALSE:  #name already used for a script
+        if res == False:  #name already used for a script
           raise ValidationError('FATAL',RESOURCE_PROVIDE_UNIQUE_NAME)
 
     filepath = self.script_filepath.get_text()
@@ -303,26 +347,45 @@ class ResourceHandler:
 
     if name == None: #New resource...
       res = self.check_unique_nfsclient_name(nfs_name)
-      if res == FALSE:  #name already used for a script
+      if res == False:  #name already used for a script
         raise ValidationError('FATAL',RESOURCE_PROVIDE_UNIQUE_NAME)
       
     else:
       if name != nfs_name:
         res = self.check_unique_nfsclient_name(nfs_name)
-        if res == FALSE:  #name already used for a script
+        if res == False:  #name already used for a script
           raise ValidationError('FATAL',RESOURCE_PROVIDE_UNIQUE_NAME)
 
+    
+    options_dir = {}
+    for opt in self.nfsc_options.get_text().strip().split(','):
+      opt = opt.strip()
+      if opt == '':
+        continue
+      options_dir[opt] = ''
+    
+    use_radios = False
+    if ('rw' in options_dir) and ('ro' in options_dir):
+      options_dir.pop('ro')
+      options_dir.pop('rw')
+      use_radios = True
+    if not(('rw' in options_dir) or ('ro' in options_dir)):
+      use_radios = True
+    if use_radios:
+      if self.nfsc_rw.get_active():
+        options_dir['rw'] = ''
+      else:
+        options_dir['ro'] = ''
+    
+    options_list = options_dir.keys()
+    options_string = options_list[0]
+    for opt in options_list[1:]:
+      options_string += ',' + opt
+    
     fields = {}
-    target = self.nfsc_target.get_text()
-    opt = self.nfsc_rw.get_active()
-    if opt == TRUE:
-      option = "rw"
-    else:
-      option = "ro"
-
     fields["name"] = nfs_name
-    fields["target"] = target
-    fields["options"] = option
+    fields["target"] = self.nfsc_target.get_text().strip()
+    fields["options"] = options_string
 
     return fields
 
@@ -335,13 +398,13 @@ class ResourceHandler:
 
     if name == None: #New resource...
       res = self.check_unique_nfsexport_name(nfse_name)
-      if res == FALSE:  #name already used for a script
+      if res == False:  #name already used for a script
         raise ValidationError('FATAL',RESOURCE_PROVIDE_UNIQUE_NAME)
       
     else:
       if name != nfse_name:
         res = self.check_unique_nfsexport_name(nfse_name)
-        if res == FALSE:  #name already used for a script
+        if res == False:  #name already used for a script
           raise ValidationError('FATAL',RESOURCE_PROVIDE_UNIQUE_NAME)
 
     fields = {}
@@ -357,13 +420,13 @@ class ResourceHandler:
 
     if name == None: #New resource...
       res = self.check_unique_netfs_name(netfs_name)
-      if res == FALSE:  #name already used for a script
+      if res == False:  #name already used for a script
         raise ValidationError('FATAL',RESOURCE_PROVIDE_UNIQUE_NAME)
       
     else:
       if name != netfs_name:
         res = self.check_unique_netfs_name(netfs_name)
-        if res == FALSE:  #name already used for a script
+        if res == False:  #name already used for a script
           raise ValidationError('FATAL',RESOURCE_PROVIDE_UNIQUE_NAME)
 
     fields = {}
@@ -374,7 +437,7 @@ class ResourceHandler:
     fields["host"] = host
     export = self.netfs_export.get_text()
     fields["export"] = export 
-    if self.netfs_fstype.get_active() == TRUE:
+    if self.netfs_fstype.get_active() == True:
       fstype = "nfs"
     else:
       fstype = "nfs4"
@@ -382,7 +445,7 @@ class ResourceHandler:
     options = self.netfs_options.get_text()
     fields["options"] = options
     unmount = self.netfs_force_unmount.get_active()
-    if unmount == FALSE:
+    if unmount == False:
       umount = "0"
     else:
       umount = "1"
@@ -398,13 +461,13 @@ class ResourceHandler:
 
     if name == None: #New resource...
       res = self.check_unique_gfs_name(gfs_name)
-      if res == FALSE:  #name already used for a script
+      if res == False:  #name already used for a script
         raise ValidationError('FATAL',RESOURCE_PROVIDE_UNIQUE_NAME)
       
     else:
       if name != gfs_name:
         res = self.check_unique_gfs_name(gfs_name)
-        if res == FALSE:  #name already used for a script
+        if res == False:  #name already used for a script
           raise ValidationError('FATAL',RESOURCE_PROVIDE_UNIQUE_NAME)
 
     fields = {}
@@ -415,37 +478,54 @@ class ResourceHandler:
     fields["device"] = device
     options = self.gfs_options.get_text()
     fields["options"] = options
-
+    if self.gfs_force_unmount.get_active():
+      force = '1'
+    else:
+      force = '0'
+    fields['force_unmount'] = force
+    
     return fields
 
 
   def val_fs(self, *argname):
     name = argname[0]
-    fs_name = self.fs_name.get_text()
+    fs_name = self.fs_name.get_text().strip()
     if fs_name == "":
       raise ValidationError('FATAL', RESOURCE_PROVIDE_NAME)
 
     if name == None: #New resource...
       res = self.check_unique_fs_name(fs_name)
-      if res == FALSE:  #name already used for a script
+      if res == False:  #name already used for a script
         raise ValidationError('FATAL',RESOURCE_PROVIDE_UNIQUE_NAME)
       
     else:
-      if name != gfs_name:
+       if name != fs_name:
         res = self.check_unique_fs_name(fs_name)
-        if res == FALSE:  #name already used for a script
+        if res == False:  #name already used for a script
           raise ValidationError('FATAL',RESOURCE_PROVIDE_UNIQUE_NAME)
 
     fields = {}
     fields["name"] = fs_name
+    
     mntp = self.fs_mnt.get_text()
     fields["mountpoint"] = mntp
+    
     device = self.fs_device.get_text()
     fields["device"] = device
-    fstypelabel = self.fs_optionmenu.get_children()[0]
-    fstype = fstypelabel.get_text()
+    
+    iter = self.fs_combo.get_active_iter()
+    fstype = self.fs_combo.get_model().get_value(iter, 0)
     fields["fstype"] = fstype
-
+    
+    if self.fs_force_unmount.get_active():
+      force = '1'
+    else:
+      force = '0'
+    fields['force_unmount'] = force
+    
+    options = self.fs_options.get_text().strip()
+    fields['options'] = options
+    
     return fields
 
   def process_widgets(self):
@@ -464,6 +544,7 @@ class ResourceHandler:
 
     self.nfsc_name = self.rc_xml.get_widget('entry8')
     self.nfsc_target = self.rc_xml.get_widget('entry9')
+    self.nfsc_options = self.rc_xml.get_widget('entry23')
     self.nfsc_rw = self.rc_xml.get_widget('radiobutton1')
     self.nfsc_ro = self.rc_xml.get_widget('radiobutton2')
 
@@ -478,13 +559,16 @@ class ResourceHandler:
     self.gfs_name = self.rc_xml.get_widget('gfs_name')
     self.gfs_mnt = self.rc_xml.get_widget('entry14')
     self.gfs_device = self.rc_xml.get_widget('entry15')
-    self.gfs_options = self.rc_xml.get_widget('entry21')
-
+    self.gfs_options = self.rc_xml.get_widget('gfs_options')
+    self.gfs_force_unmount = self.rc_xml.get_widget('gfs_force_unmount')
+    
     self.fs_name = self.rc_xml.get_widget('entry11')
-    self.fs_optionmenu = self.rc_xml.get_widget('optionmenu2')
     self.fs_mnt = self.rc_xml.get_widget('entry12')
     self.fs_device = self.rc_xml.get_widget('fs_dev')
-
+    self.fs_combo = self.rc_xml.get_widget('combobox1')
+    self.fs_force_unmount = self.rc_xml.get_widget('fs_force_unmount')
+    self.fs_options = self.rc_xml.get_widget('fs_options')
+  
   def set_model(self, model_builder):
     self.model_builder = model_builder
 
@@ -492,55 +576,55 @@ class ResourceHandler:
     rcs = self.model_builder.getResources()
     for rc in rcs:
       if rc.getName() == fs_name:
-        return FALSE
+        return False
 
-    return TRUE
+    return True
 
   def check_unique_netfs_name(self,netfs_name):
     rcs = self.model_builder.getResources()
     for rc in rcs:
       if rc.getName() == netfs_name:
-        return FALSE
+        return False
 
-    return TRUE
+    return True
 
   def check_unique_gfs_name(self,gfs_name):
     rcs = self.model_builder.getResources()
     for rc in rcs:
       if rc.getName() == gfs_name:
-        return FALSE
+        return False
 
-    return TRUE
+    return True
 
   def check_unique_script_name(self,name):
     rcs = self.model_builder.getResources()
     for rc in rcs:
       if rc.getName() == name:
-        return FALSE
+        return False
 
-    return TRUE
+    return True
 
   def check_unique_ip(self,addr):
     rcs = self.model_builder.getResources()
     for rc in rcs:
       if rc.getName() == addr:
-        return FALSE
+        return False
 
-    return TRUE
+    return True
 
   def check_unique_nfsexport_name(self,name):
     rcs = self.model_builder.getResources()
     for rc in rcs:
       if rc.getName() == name:
-        return FALSE
+        return False
 
-    return TRUE
+    return True
 
   def check_unique_nfsclient_name(self,name):
     rcs = self.model_builder.getResources()
     for rc in rcs:
       if rc.getName() == name:
-        return FALSE
+        return False
 
-    return TRUE
+    return True
 
