@@ -1,7 +1,6 @@
 from Service import Service
 from ResourceHandler import *
 import gobject
-from gtk import TRUE, FALSE
 from clui_constants import *
 from RefObject import RefObject
 
@@ -24,6 +23,8 @@ NONE_PLACEHOLDER=_("None")
 
 EXCLUSIVE_STR = "exclusive"
 
+AUTOSTART_STR = "autostart"
+
 ###YUK! XXX make access to this static in ResourceHandler
 ###This is an awful copy
 RC_OPTS = {"ip":_("IP Address"),
@@ -37,6 +38,7 @@ RC_OPTS = {"ip":_("IP Address"),
 
 SHARED_RESOURCE=_("Shared")
 PRIVATE_RESOURCE=_("Private")
+CANT_ATTACH=_("The selected Resource Type: \"%s\", does not support attached children of any type. Sorry.")
 
 class ServiceController:
   def __init__(self, glade_xml,model_builder,reset_tree_model):
@@ -48,10 +50,10 @@ class ServiceController:
     self.process_widgets()
     self.rm_ptr = self.model_builder.getResourceManagerPtr()
     self.current_service = None
-    self.prepset = FALSE
-    self.foreach_found_sentinel = FALSE
-    self.isNewResource = FALSE
-    self.isAttachedResource = FALSE
+    self.prepset = False
+    self.foreach_found_sentinel = False
+    self.isNewResource = False
+    self.isAttachedResource = False
     
 
   def process_widgets(self):
@@ -111,6 +113,9 @@ class ServiceController:
     self.glade_xml.get_widget('on_shared_rc_ok').connect('clicked',self.on_shared_rc_ok)
     self.glade_xml.get_widget('on_shared_rc_cancel').connect('clicked',self.on_shared_rc_cancel)
 
+    self.autostart_cbox = self.glade_xml.get_widget('autostart_cbox')
+    self.autostart_cbox.connect('toggled',self.on_autostart_cbox_changed)
+
     self.exclusive_cbox = self.glade_xml.get_widget('exclusive_cbox')
     self.exclusive_cbox.connect('toggled',self.on_exclusive_cbox_changed)
     self.rc_proxy = self.glade_xml.get_widget('svc_rc_proxy')
@@ -140,24 +145,23 @@ class ServiceController:
       m.show()
       menu.append(m)
       for fdom in faildoms:
-        m = gtk.MenuItem(fdom.getName())
+        namestr = fdom.getName()
+        namestr = namestr.replace("_","__")
+
+        m = gtk.MenuItem(namestr)
         m.show()
         menu.append(m)
-    self.prepset = TRUE
     self.svc_fdom_optionmenu.set_menu(menu)
 
   def on_fdom_option_changed(self, *args):
-    if self.prepset == TRUE:
-      print "PREPSET is TRUE"
-      self.prepset = FALSE
+    if self.prepset == True:
       return
     else:
       if self.svc_fdom_optionmenu.get_history() == 0:
-        print "history == 0"
         retval = self.current_service.removeAttribute("domain")
-        return
-      lbl = self.svc_fdom_optionmenu.get_children()[0]
-      self.current_service.addAttribute("domain",lbl.get_text())
+      else:
+        lbl = self.svc_fdom_optionmenu.get_children()[0]
+        self.current_service.addAttribute("domain",lbl.get_text())
       self.model_builder.setModified()
 
     
@@ -175,13 +179,13 @@ class ServiceController:
 
   def on_add_shared(self, button):
     self.populate_shared_tree()
-    self.isAttachedResource = FALSE
+    self.isAttachedResource = False
     #self.shared_rc_panel.show()
     self.shared_rc_panel.run()
 
   def on_add_private(self, button):
-    self.isNewResource = TRUE
-    self.isAttachedResource = FALSE
+    self.isNewResource = True
+    self.isAttachedResource = False
     self.rc_handler.clear_rc_forms()
     self.rc_options.set_history(0)
     self.rc_options.show()
@@ -195,8 +199,18 @@ class ServiceController:
     self.svc_rc_panel.run()
  
   def on_attach_private(self, button):
-    self.isNewResource = TRUE
-    self.isAttachedResource = TRUE
+    #Hold it -- before we do ANYTHING here, let's check if the 
+    #object selected to have an attached child will allow children...
+    selection = self.svc_treeview.get_selection()
+    model, iter = selection.get_selected()
+    if iter == None:
+      return
+    obj = model.get_value(iter, R_OBJ_COL)
+    if obj.isDenyAll() == True:
+      retval = MessageLibrary.errorMessage(CANT_ATTACH % self.rc_prettyname_hash[obj.getTagName()])
+      return
+    self.isNewResource = True
+    self.isAttachedResource = True
     self.rc_handler.clear_rc_forms()
     self.rc_options.set_history(0)
     self.rc_options.show()
@@ -210,8 +224,18 @@ class ServiceController:
     self.svc_rc_panel.run()
 
   def on_attach_shared(self, button):
+    #Once again (as above) -- before we do ANYTHING here, let's check if the 
+    #object selected to have an attached child will allow children...
+    selection = self.svc_treeview.get_selection()
+    model, iter = selection.get_selected()
+    if iter == None:
+      return
+    obj = model.get_value(iter, R_OBJ_COL)
+    if obj.isDenyAll() == True:
+      retval = MessageLibrary.errorMessage(CANT_ATTACH % self.rc_prettyname_hash[obj.getTagName()])
+      return
     self.populate_shared_tree()
-    self.isAttachedResource = TRUE
+    self.isAttachedResource = True
     #self.shared_rc_panel.show()
     self.shared_rc_panel.run()
 
@@ -220,7 +244,7 @@ class ServiceController:
     model,iter = selection.get_selected()
     self.rc_options.hide()
     rc_obj = model.get_value(iter, R_OBJ_COL)
-    self.isNewResource = FALSE
+    self.isNewResource = False
     attrs = rc_obj.getAttributes()
     tagname = rc_obj.getTagName()
     self.rc_dlg_label.set_markup(RC_PROPS % (self.rc_prettyname_hash[tagname],rc_obj.getName()))
@@ -252,21 +276,23 @@ class ServiceController:
     selection = self.svc_treeview.get_selection()
     model,iter = selection.get_selected()
     if iter == None:
-      self.attach_new_rc.set_sensitive(FALSE)
-      self.attach_shared_rc.set_sensitive(FALSE)
-      self.del_rc_button.set_sensitive(FALSE)
-      self.edit_rc_button.set_sensitive(FALSE)
+      self.attach_new_rc.set_sensitive(False)
+      self.attach_shared_rc.set_sensitive(False)
+      self.del_rc_button.set_sensitive(False)
+      self.edit_rc_button.set_sensitive(False)
       return
     else:
       #if appropriate, edit selection
       obj = model.get_value(iter, R_OBJ_COL)
-      if obj.isRefObject() == TRUE:
-        self.edit_rc_button.set_sensitive(FALSE)
+      if obj.isRefObject() == True:
+        self.edit_rc_button.set_sensitive(False)
       else:
-        self.edit_rc_button.set_sensitive(TRUE)
+        self.edit_rc_button.set_sensitive(True)
 
 
   def prep_service_panel(self, svc):
+    self.prepset = True
+    
     self.current_service = svc
     if self.current_service != None:  
       self.service_name_label.set_markup("<span><b>" + svc.getName() + "</b></span>")
@@ -274,13 +300,22 @@ class ServiceController:
       #if necessary, set exclusive checkbox
       exclusive_state = svc.getAttribute(EXCLUSIVE_STR)
       if (exclusive_state == None) or (exclusive_state == "0"):
-        self.exclusive_cbox.set_active(FALSE)
+        self.exclusive_cbox.set_active(False)
       else:
-        self.exclusive_cbox.set_active(TRUE)
+        self.exclusive_cbox.set_active(True)
+
+      #and if necessary, set autostart checkbox
+      autostart_state = svc.getAttribute(AUTOSTART_STR)
+      if (autostart_state == None) or (autostart_state == "0"):
+        self.autostart_cbox.set_active(False)
+      else:
+        self.autostart_cbox.set_active(True)
 
       self.populate_fdom_optionmenu()
       self.prep_service_tree()
-
+      
+      self.prepset = False
+  
   def prep_service_tree(self):
     resources = self.current_service.getChildren()
     treemodel = self.svc_treeview.get_model()
@@ -289,13 +324,14 @@ class ServiceController:
       iter = treemodel.append(None)
       self.add_tree_children(child, iter)
 
+    self.svc_treeview.expand_all()
+
     self.svc_treeview.get_selection().unselect_all()
-    self.attach_new_rc.set_sensitive(FALSE)
-    self.attach_shared_rc.set_sensitive(FALSE)
-    self.del_rc_button.set_sensitive(FALSE)
-    self.edit_rc_button.set_sensitive(FALSE)
+    self.attach_new_rc.set_sensitive(False)
+    self.attach_shared_rc.set_sensitive(False)
+    self.del_rc_button.set_sensitive(False)
+    self.edit_rc_button.set_sensitive(False)
 
-    #self.prepset = TRUE
     domain = self.current_service.getAttribute("domain")
     if domain == None:
       self.svc_fdom_optionmenu.set_history(0)
@@ -309,10 +345,10 @@ class ServiceController:
           if item.get_children()[0].get_text() == domain:
             break
       self.svc_fdom_optionmenu.set_history(y)
-
+    
   def add_tree_children(self, obj, iter):
     treemodel = self.svc_treeview.get_model()
-    if obj.isRefObject() == TRUE:
+    if obj.isRefObject() == True:
       str_buf = SHARED_RESOURCE
     else:
       str_buf = PRIVATE_RESOURCE
@@ -366,7 +402,7 @@ class ServiceController:
     if iter != None:
       type = model.get_value(iter, R_TYPE_COL)
       r_obj = model.get_value(iter, R_OBJ_COL)
-    if self.isNewResource == FALSE:  #edit
+    if self.isNewResource == False:  #edit
       tagname = r_obj.getTagName()
       if tagname == "ip":
         returnlist = self.rc_handler.validate_resource(tagname, r_obj.getAttribute("address"))
@@ -388,7 +424,7 @@ class ServiceController:
         self.svc_rc_panel.hide()
         for x in returnlist.keys():
           newobj.addAttribute(x,returnlist[x])
-        if self.isAttachedResource == FALSE:
+        if self.isAttachedResource == False:
           self.current_service.addChild(newobj)
         else:
           r_obj.addChild(newobj)
@@ -397,8 +433,8 @@ class ServiceController:
                                                                                 
   def rc_panel_cancel(self, button):
     self.svc_rc_panel.hide()
-    self.isNewResource = FALSE
-    self.isAttachedResource = FALSE
+    self.isNewResource = False
+    self.isAttachedResource = False
     self.rc_handler.clear_rc_forms()
 
   def on_shared_rc_ok(self, button):
@@ -406,12 +442,12 @@ class ServiceController:
     model,iter = selection.get_selected()
     if iter == None:
       self.shared_rc_panel.hide()
-      self.isNewResource = FALSE
-      self.isAttachedResource = FALSE
+      self.isNewResource = False
+      self.isAttachedResource = False
       return
     r_obj = model.get_value(iter, S_OBJ_COL)
     rf = RefObject(r_obj)
-    if self.isAttachedResource == TRUE:
+    if self.isAttachedResource == True:
       selection = self.svc_treeview.get_selection()
       smodel,iter = selection.get_selected()
       rc_obj = smodel.get_value(iter, R_OBJ_COL)
@@ -423,38 +459,52 @@ class ServiceController:
     self.shared_rc_panel.hide()
 
   def on_exclusive_cbox_changed(self, *args):
-    if self.exclusive_cbox.get_active() == TRUE:
+    if self.prepset == True:
+      return
+    self.model_builder.setModified()
+    if self.exclusive_cbox.get_active() == True:
       self.current_service.addAttribute(EXCLUSIVE_STR,"1")
     else:
       retval = self.current_service.getAttribute(EXCLUSIVE_STR)
       if retval != None:
         self.current_service.removeAttribute(EXCLUSIVE_STR)
                                                                                 
+  def on_autostart_cbox_changed(self, *args):
+    if self.prepset == True:
+      return
+    self.model_builder.setModified()
+    if self.autostart_cbox.get_active() == True:
+      self.current_service.addAttribute(AUTOSTART_STR,"1")
+    else:
+      retval = self.current_service.getAttribute(AUTOSTART_STR)
+      if retval != None:
+        self.current_service.removeAttribute(AUTOSTART_STR)
+                                                                                
   def on_shared_rc_cancel(self, button):
     self.shared_rc_panel.hide()
-    self.isNewResource = FALSE
-    self.isAttachedResource = FALSE
+    self.isNewResource = False
+    self.isAttachedResource = False
                                                                                 
   def svc_rc_panel_delete(self, *args):
     self.svc_rc_panel.hide()
-    self.isNewResource = FALSE
-    self.isAttachedResource = FALSE
-    return gtk.TRUE
+    self.isNewResource = False
+    self.isAttachedResource = False
+    return True
  
   def shared_rc_panel_delete(self, *args):
     self.shared_rc_panel.hide()
-    self.isNewResource = FALSE
-    self.isAttachedResource = FALSE
-    return gtk.TRUE
+    self.isNewResource = False
+    self.isAttachedResource = False
+    return True
 
   def cleanup_panels(self):
-    self.isNewResource = FALSE
-    self.isAttachedResource = FALSE
+    self.isNewResource = False
+    self.isAttachedResource = False
     self.svc_rc_panel.hide()
     self.shared_rc_panel.hide()
 
   def all_buttons_on(self): 
-    self.attach_new_rc.set_sensitive(TRUE)
-    self.attach_shared_rc.set_sensitive(TRUE)
-    self.del_rc_button.set_sensitive(TRUE)
-    self.edit_rc_button.set_sensitive(TRUE)
+    self.attach_new_rc.set_sensitive(True)
+    self.attach_shared_rc.set_sensitive(True)
+    self.del_rc_button.set_sensitive(True)
+    self.edit_rc_button.set_sensitive(True)
