@@ -14,7 +14,6 @@ import select
 import signal
 import string
 import os
-from gtk import TRUE, FALSE
 import MessageLibrary
 from CommandHandler import CommandHandler
 from CommandError import CommandError
@@ -62,7 +61,8 @@ gnome.app_version = VERSION
 FORMALNAME=_("system-config-cluster")
 ABOUT_VERSION=_("%s %s") % ('system-config-cluster',VERSION)
  
-NO_CONF_PRESENT=_("The cluster configuration file, '/etc/cluster/cluster.conf' does not exist on this system. This application will help you build an initial configuration file, or you can open an existing configuration file in another location by selecting 'Open' in the file drop down menu.") 
+NO_CONF_PRESENT=_("The cluster configuration file, '/etc/cluster/cluster.conf' does not exist on this system. This application will help you build an initial configuration file, or you can open an existing configuration file in another location.")
+NO_CONF_PRESENT_INVALID=_("The cluster configuration file, '/etc/cluster/cluster.conf' is not valid. This application will help you build an initial configuration file, or you can open an existing configuration file in another location.")
 
 NOT_CLUSTER_MEMBER=_("Because this node is not currently part of a cluster, the management tab for this application is not available.")
 
@@ -76,6 +76,9 @@ NO_MCAST_IP=_("Please Provide a Valid Multicast IP Address")
 PROPOGATION_CONFIRMATION=_("Success. The current configuration has been propagated to the cluster.")
 
 FILE_DOES_NOT_EXIST=_("The file %s does not exist on the filesystem.")
+
+CONFFILE_NOT_SAVED_MESSAGE=_("Configuration file not saved.")
+
 ###############################################
 class basecluster:
   def __init__(self, glade_xml, app):
@@ -96,59 +99,47 @@ class basecluster:
 
     mb = ModelBuilder(1)
     is_cluster_member = mb.isClusterMember()
-
-    if (conf_exists == FALSE):
-      #hide mgmt tab
-      self.mgmt_tab.hide()
-      self.no_conf_label.set_text(NO_CONF_PRESENT + "\n\n" + NOT_CLUSTER_MEMBER)
-      self.propagate_button.hide()
-      #self.no_conf_dlg.show()
-      self.no_conf_dlg.run()
-    elif ((conf_exists == TRUE) and (is_cluster_member == FALSE)):
-      self.model_builder = ModelBuilder(1, CLUSTER_CONF_PATH)
-      self.mgmt_tab.hide()
-      MessageLibrary.simpleInfoMessage(NOT_CLUSTER_MEMBER)
-      self.propagate_button.hide()
-      try:
-        self.command_handler.check_xml(CLUSTER_CONF_PATH)
-      except CommandError, e:
-        self.bad_xml_label.set_text(XML_CONFIG_ERROR % CLUSTER_CONF_PATH)
-        self.bad_xml_text.get_buffer().set_text(e.getMessage())
-        retval = self.bad_xml_dlg.run()
-        if retval == gtk.RESPONSE_CANCEL:
-          #gtk.main_quit() 
-          sys.exit(0)
-        elif retval == gtk.RESPONSE_APPLY:
-          #make new cfg file
-          self.bad_xml_dlg.hide()
-          self.no_conf_dlg.run()
-        else:  #Proceed anyway...
-          self.bad_xml_dlg.hide()
-          self.model_builder = ModelBuilder(1, CLUSTER_CONF_PATH)
+    
+    if conf_exists:
+        use_default_clusterconf_path = True
+        try:
+            self.command_handler.check_xml(CLUSTER_CONF_PATH)
+        except CommandError, e:
+            self.bad_xml_label.set_text(XML_CONFIG_ERROR % CLUSTER_CONF_PATH)
+            self.bad_xml_text.get_buffer().set_text(e.getMessage())
+            retval = self.bad_xml_dlg.run()
+            self.bad_xml_dlg.hide()
+            if retval == gtk.RESPONSE_APPLY:
+                # make new cfg file
+                use_default_clusterconf_path = False
+                self.on_no_conf_create(None)
+            elif retval == gtk.RESPONSE_OK:
+                # Proceed anyway...
+                pass
+            else:
+                use_default_clusterconf_path = False
+                self.no_conf_label.set_text(NO_CONF_PRESENT_INVALID)
+                self.no_conf_dlg.run()
+        if use_default_clusterconf_path:
+            self.model_builder = ModelBuilder(1, CLUSTER_CONF_PATH)
+        if is_cluster_member:
+            self.propagate_button.show()
+            self.mgmttab = MgmtTab(glade_xml, self.model_builder,self.winMain)
+        else:
+            self.mgmt_tab.hide()
+            MessageLibrary.simpleInfoMessage(NOT_CLUSTER_MEMBER)
+            self.propagate_button.hide()
     else:
-      self.model_builder = ModelBuilder(1, CLUSTER_CONF_PATH)
-      self.propagate_button.show()
-      try:
-        self.command_handler.check_xml(CLUSTER_CONF_PATH)
-      except CommandError, e:
-        self.bad_xml_label.set_text(XML_CONFIG_ERROR % CLUSTER_CONF_PATH)
-        self.bad_xml_text.get_buffer().set_text(e.getMessage())
-        retval = self.bad_xml_dlg.run()
-        if retval == gtk.RESPONSE_CANCEL:
-          #gtk.main_quit()
-          sys.exit(0)
-        elif retval == gtk.RESPONSE_APPLY:
-          #make new cfg file
-          self.bad_xml_dlg.hide()
-          self.no_conf_dlg.run()
-        else:  #Proceed anyway...
-          self.bad_xml_dlg.hide()
-          self.model_builder = ModelBuilder(1, CLUSTER_CONF_PATH)
-      self.mgmttab = MgmtTab(glade_xml, self.model_builder,self.winMain)
-
+        #hide mgmt tab
+        self.mgmt_tab.hide()
+        self.no_conf_label.set_text(NO_CONF_PRESENT + "\n\n" + NOT_CLUSTER_MEMBER)
+        self.propagate_button.hide()
+        # self.no_conf_dlg.show()
+        self.no_conf_dlg.run()
+    
     self.configtab = ConfigTab(glade_xml, self.model_builder)
-
-
+    
+    
     self.glade_xml.signal_autoconnect(
       {
         "on_quit1_activate" : self.quit,
@@ -182,10 +173,10 @@ class basecluster:
   def quit(self, *args):
     path = self.model_builder.getFilepath()
     mod = self.model_builder.isFileModified()
-    if (path == "") or (path == None) or (mod == TRUE):
+    if (path == "") or (path == None) or (mod == True):
       retval = MessageLibrary.warningMessage(UNSAVED)
       if retval == gtk.RESPONSE_YES:
-        return gtk.TRUE
+        return True
       else:
         gtk.main_quit()
 
@@ -196,86 +187,95 @@ class basecluster:
     popup = gtk.FileSelection()
     popup.set_filename(CLUSTER_CONF_DIR_PATH)
     popup.hide_fileop_buttons()
-    popup.set_select_multiple(FALSE)
+    popup.set_select_multiple(False)
     popup.show_all()
-    rc = popup.run()
-    filepath = popup.get_filename()
-
-    #Check to see if file actually exists
-    path_exists = os.path.exists(filepath)
-    if path_exists == FALSE:
-      MessageLibrary.errorMessage(FILE_DOES_NOT_EXIST % filepath)
-      popup.destroy()
-      return
+    
+    while popup.run() == gtk.RESPONSE_OK:
+        filepath = popup.get_filename()
+        #Check to see if file actually exists
+        if not os.path.exists(filepath):
+            MessageLibrary.errorMessage(FILE_DOES_NOT_EXIST % filepath)
+            continue
+        elif os.path.isdir(filepath):
+            continue
+        # process file
+        try:
+            self.command_handler.check_xml(filepath)
+        except CommandError, e:
+            self.bad_xml_label.set_text(XML_CONFIG_ERROR % filepath)
+            self.bad_xml_text.get_buffer().set_text(e.getMessage())
+            retval = self.bad_xml_dlg.run()
+            self.bad_xml_dlg.hide()
+            if retval == gtk.RESPONSE_OK:
+                #Proceed anyway...
+                pass
+            elif retval == gtk.RESPONSE_APPLY:
+                # make new cfg file
+                popup.destroy()
+                self.on_no_conf_create(None)
+                return
+            else:
+                continue
+        self.model_builder = ModelBuilder(DLM_TYPE, filepath)
+        self.configtab.set_model(self.model_builder)
+        break
+    popup.destroy()
   
-    if os.path.isdir(filepath):
-      popup.destroy()
-      return
-    if not rc == gtk.RESPONSE_OK:
-      popup.destroy()
-      return
-    else:
-      try:
-        self.command_handler.check_xml(filepath)
-      except CommandError, e:
-        self.bad_xml_label.set_text(XML_CONFIG_ERROR % filepath)
-        self.bad_xml_text.get_buffer().set_text(e.getMessage())
-        retval = self.bad_xml_dlg.run()
-        if retval == gtk.RESPONSE_CANCEL:
-          sys.exit(0)
-          #gtk.main_quit() 
-        elif retval == gtk.RESPONSE_APPLY:
-          #make new cfg file
-          popup.destroy()
-          self.bad_xml_dlg.hide()
-          self.no_conf_dlg.run()
-          return
-        else:  #Proceed anyway...
-          self.bad_xml_dlg.hide()
-          self.model_builder = ModelBuilder(DLM_TYPE, filepath)
-          self.configtab.set_model(self.model_builder)
-          popup.destroy()
-          return
-      self.model_builder = ModelBuilder(DLM_TYPE, filepath)
-      self.configtab.set_model(self.model_builder)
-      popup.destroy()
-
   def open_limited(self, *args):
     #offer fileselection
     popup = gtk.FileSelection()
     popup.set_filename(CLUSTER_CONF_DIR_PATH)
     popup.hide_fileop_buttons()
-    popup.set_select_multiple(FALSE)
+    popup.set_select_multiple(False)
     popup.show_all()
-    rc = popup.run()
-    filepath = popup.get_filename()
-
-    #Check to see if file actually exists
-    path_exists = os.path.exists(filepath)
-    if path_exists == FALSE:
-      MessageLibrary.errorMessage(FILE_DOES_NOT_EXIST % filepath)
-      popup.destroy()
-      self.model_builder = ModelBuilder(DLM_TYPE, None)
-      return
+    
+    while True:
+        rc = popup.run()
+        
+        if rc != gtk.RESPONSE_OK:
+            popup.destroy()
+            self.no_conf_dlg.run()
+            return
+        
+        filepath = popup.get_filename()
+        #Check to see if file actually exists
+        if not os.path.exists(filepath):
+            MessageLibrary.errorMessage(FILE_DOES_NOT_EXIST % filepath)
+            continue
+        elif os.path.isdir(filepath):
+            continue
+        # process file
+        try:
+            self.command_handler.check_xml(filepath)
+        except CommandError, e:
+            self.bad_xml_label.set_text(XML_CONFIG_ERROR % filepath)
+            self.bad_xml_text.get_buffer().set_text(e.getMessage())
+            retval = self.bad_xml_dlg.run()
+            self.bad_xml_dlg.hide()
+            if retval == gtk.RESPONSE_OK:
+                #Proceed anyway...
+                popup.destroy()
+                self.model_builder = ModelBuilder(DLM_TYPE, filepath)
+                return
+            elif retval == gtk.RESPONSE_APPLY:
+                # make new cfg file
+                popup.destroy()
+                self.on_no_conf_create(None)
+                return
+            else:  
+                continue
+        popup.destroy()
+        self.model_builder = ModelBuilder(DLM_TYPE, filepath)
+        return
   
-    if os.path.isdir(filepath):
-      popup.destroy()
-      self.model_builder = ModelBuilder(DLM_TYPE, None)
-      return
-    if not rc == gtk.RESPONSE_OK:
-      popup.destroy()
-      self.model_builder = ModelBuilder(DLM_TYPE, None)
-      return
-    else:
-      self.model_builder = ModelBuilder(DLM_TYPE, filepath)
-      popup.destroy()
-
   def save(self, *args):
     if self.model_builder.has_filepath():
       fp = self.model_builder.getFilepath()
-      if self.model_builder.exportModel() == TRUE:
+      if self.model_builder.exportModel() == True:
           retval = MessageLibrary.simpleInfoMessage(SAVED_FILE % fp)
-          self.configtab.prepare_tree(TRUE)
+          self.configtab.prepare_tree(True)
+      else:
+          MessageLibrary.errorMessage(CONFFILE_NOT_SAVED_MESSAGE)
     else:  #Must have been a 'New' instance...
       self.save_as(None)
 
@@ -290,7 +290,7 @@ class basecluster:
     popup = gtk.FileSelection()
     popup.set_filename(fname)
     popup.show_fileop_buttons()
-    popup.set_select_multiple(FALSE)
+    popup.set_select_multiple(False)
     popup.show_all()
     rc = popup.run()
     filepath = popup.get_filename()
@@ -299,21 +299,24 @@ class basecluster:
       return
     else:
       try:
-        if self.model_builder.exportModel(filepath) == TRUE:
+        if self.model_builder.exportModel(filepath) == True:
             retval = MessageLibrary.simpleInfoMessage(SAVED_FILE % filepath)
             self.glade_xml.get_widget("filename_entry").set_text(filepath)
+        else:
+            MessageLibrary.errorMessage(CONFFILE_NOT_SAVED_MESSAGE)
       except IOError, e:
         MessageLibrary.errorMessage("Something ugly happened when attempting to write output file")
     popup.destroy()
 
   def new(self, *args):
     #Ask what type of lockserver to employ
-    self.mcast_cbox.set_sensitive(TRUE)
-    self.mcast_cbox.set_active(FALSE)
-    self.ip.set_sensitive(FALSE)
+    self.mcast_cbox.set_sensitive(True)
+    self.mcast_cbox.set_active(False)
+    self.ip.clear()
+    self.ip.set_sensitive(False)
     self.mcast_address = None
-    self.mcast_addr_label.set_sensitive(FALSE)
-    self.radio_dlm.set_active(TRUE)
+    self.mcast_addr_label.set_sensitive(False)
+    self.radio_dlm.set_active(True)
     self.lock_method_dlg.show()
     #print "So now the mcast_addr == %s" % self.mcast_address
     #self.model_builder = ModelBuilder(self.lock_type, None, self.mcast_address)
@@ -322,13 +325,13 @@ class basecluster:
     #self.configtab.set_model(self.model_builder)
 
   def lock_ok(self, button):
-
-    if self.radio_dlm.get_active() == TRUE:
-      if self.mcast_cbox.get_active() == TRUE: #User wishes to use multicast
-        if self.ip.isValid() == FALSE:
+    if self.radio_dlm.get_active() == True:
+      if self.mcast_cbox.get_active() == True: #User wishes to use multicast
+        if self.ip.isValid() == False:
           retval = MessageLibrary.errorMessage(NO_MCAST_IP)
           self.mcast_address = None
-          return
+          self.lock_method_dlg.response(gtk.RESPONSE_NO)
+          return True
         else:
           self.mcast_address = self.ip.getAddrAsString() 
       self.lock_type = DLM_TYPE
@@ -343,44 +346,42 @@ class basecluster:
     if self.configtab != None:
       self.configtab.set_model(self.model_builder)
 
-  def lock_method_delete(self, *args):
-    self.lock_type = DLM_TYPE
-    self.lock_method_dlg.hide()
-    return gtk.TRUE
-
   def on_no_conf_create(self, button):
     self.no_conf_dlg.hide()
-    self.radio_dlm.set_active(TRUE)
-    self.mcast_cbox.set_sensitive(TRUE)
-    self.mcast_cbox.set_active(FALSE)
-    self.ip.set_sensitive(FALSE)
-    self.mcast_addr_label.set_sensitive(FALSE)
-    self.lock_method_dlg.show_all()
-    retval = self.lock_method_dlg.run()
-    self.lock_method_dlg.hide()
-    self.model_builder = ModelBuilder(self.lock_type)
-    
+    self.radio_dlm.set_active(True)
+    self.mcast_cbox.set_sensitive(True)
+    self.mcast_cbox.set_active(False)
+    self.ip.clear()
+    self.ip.set_sensitive(False)
+    self.mcast_addr_label.set_sensitive(False)
+    while self.lock_method_dlg.run() != gtk.RESPONSE_OK:
+        # continue ONLY after self.model_builder has been set up
+        pass
+  
   def on_no_conf_open(self, button):
     self.no_conf_dlg.hide()
     self.open_limited(None)
-
+  
+  def on_no_conf_quit(self, button):
+      sys.exit(0)
+  
   def on_mcast_cbox_changed(self, *args):
-    if self.mcast_cbox.get_active() == FALSE:
-      self.ip.set_sensitive(FALSE)
-      self.mcast_addr_label.set_sensitive(FALSE)
+    if self.mcast_cbox.get_active() == False:
+      self.ip.set_sensitive(False)
+      self.mcast_addr_label.set_sensitive(False)
     else:
-      self.ip.set_sensitive(TRUE)
-      self.mcast_addr_label.set_sensitive(TRUE)
+      self.ip.set_sensitive(True)
+      self.mcast_addr_label.set_sensitive(True)
 
   def on_radio_change(self, *args):
-    if self.radio_dlm.get_active() == FALSE:
-      self.mcast_cbox.set_sensitive(FALSE)
-      self.ip.set_sensitive(FALSE)
-      self.mcast_addr_label.set_sensitive(FALSE)
+    if self.radio_dlm.get_active() == False:
+      self.mcast_cbox.set_sensitive(False)
+      self.ip.set_sensitive(False)
+      self.mcast_addr_label.set_sensitive(False)
     else:
-      self.mcast_cbox.set_sensitive(TRUE)
-      self.ip.set_sensitive(TRUE)
-      self.mcast_addr_label.set_sensitive(TRUE)
+      self.mcast_cbox.set_sensitive(True)
+      self.ip.set_sensitive(True)
+      self.mcast_addr_label.set_sensitive(True)
     
 
   def init_widgets(self):
@@ -403,9 +404,11 @@ class basecluster:
     self.lock_method_dlg.connect("delete_event", self.lock_method_dlg_delete)
     self.glade_xml.get_widget('okbutton17').connect('clicked', self.lock_ok)
     self.no_conf_dlg = self.glade_xml.get_widget('no_conf')
+    self.no_conf_dlg.connect("delete_event",self.on_no_conf_dlg_delete)
     self.no_conf_label = self.glade_xml.get_widget('no_conf_label')
     self.glade_xml.get_widget('no_conf_create').connect('clicked',self.on_no_conf_create)
     self.glade_xml.get_widget('no_conf_open').connect('clicked',self.on_no_conf_open)
+    self.glade_xml.get_widget('no_conf_quit').connect('clicked',self.on_no_conf_quit)
     self.propagate_button = self.glade_xml.get_widget('propagate')
     self.propagate_button.connect('clicked', self.propagate)
     self.bad_xml_dlg = self.glade_xml.get_widget('bad_xml_dlg')
@@ -422,14 +425,17 @@ class basecluster:
     self.glade_xml.get_widget('mcast_addr_entry_proxy').add(self.mcast_addr_entry)
     self.mcast_ip_dlg = self.glade_xml.get_widget('mcast_ip_dlg')
     self.mcast_ip_dlg.connect("delete_event", self.mcast_ip_dlg_delete)
-    self.lock_method_dlg.connect("delete_event", self.lock_method_dlg_delete)
 
   def propagate(self, button):
     retval = MessageLibrary.warningMessage(CONFIRM_PROPAGATE)
     if retval == gtk.RESPONSE_NO:
       return
+
     #1 save file to /etc/cluster/cluster.conf
-    if self.model_builder.exportModel(CLUSTER_CONF_PATH) == False:
+    if self.model_builder.exportModel(CLUSTER_CONF_PATH) == True:
+        self.configtab.prepare_tree(True)
+    else:
+        MessageLibrary.errorMessage(_("Propagation aborted."))
         return
     #2 call ccs_tool
     try:
@@ -460,48 +466,55 @@ class basecluster:
     #call model builder call
     self.model_builder.switch_lockservers()
     #call configtab.prepare_tree()
-    #self.configtab.prepare_tree(TRUE)
+    #self.configtab.prepare_tree(True)
     self.configtab.reset_tree_model(None)
 
   def swap_multicast_state(self, *args):
     address = None
-    if self.model_builder.isMulticast() == FALSE:
-      self.mcast_addr_entry.clear()
-      retval = self.mcast_ip_dlg.run()
-      if retval == gtk.RESPONSE_OK:
-        address = self.mcast_addr_entry.getAddrAsString()
-        self.mcast_ip_dlg.hide()
-      else:
-        self.mcast_ip_dlg.hide()
-        return
-         
-    self.model_builder.swap_multicast_state(address)
+    if self.model_builder.isMulticast() == False:
+        self.mcast_addr_entry.clear()
+        while address == None:
+            retval = self.mcast_ip_dlg.run()
+            if retval == gtk.RESPONSE_OK:
+                if self.mcast_addr_entry.isValid():
+                    address = self.mcast_addr_entry.getAddrAsString()
+                    self.mcast_ip_dlg.hide()
+                else:
+                    MessageLibrary.errorMessage(NO_MCAST_IP)
+                    continue
+            else:
+                self.mcast_ip_dlg.hide()
+                return
     
-    self.configtab.prepare_tree(TRUE)
-
+    self.model_builder.swap_multicast_state(address)
+    self.configtab.prepare_tree(True)
+    self.configtab.reset_tree_model(None)
+  
   def on_notebook_change(self, notebook, page, pagenum, *data):
     if pagenum == 0:  #Config page
       #turn on all menus
-      self.tools1.set_sensitive(TRUE)
-      self.new1.set_sensitive(TRUE)
-      self.open1.set_sensitive(TRUE)
-      self.save1.set_sensitive(TRUE)
-      self.save_as1.set_sensitive(TRUE)
+      self.tools1.set_sensitive(True)
+      self.new1.set_sensitive(True)
+      self.open1.set_sensitive(True)
+      self.save1.set_sensitive(True)
+      self.save_as1.set_sensitive(True)
     else:
       #turn off all but quit and help
-      self.tools1.set_sensitive(FALSE)
-      self.new1.set_sensitive(FALSE)
-      self.open1.set_sensitive(FALSE)
-      self.save1.set_sensitive(FALSE)
-      self.save_as1.set_sensitive(FALSE)
+      self.tools1.set_sensitive(False)
+      self.new1.set_sensitive(False)
+      self.open1.set_sensitive(False)
+      self.save1.set_sensitive(False)
+      self.save_as1.set_sensitive(False)
 
   def lock_method_dlg_delete(self, *args):
-    self.lock_method_dlg.hide()
-    return gtk.TRUE
+    return True
 
   def mcast_ip_dlg_delete(self, *args):
     self.mcast_ip_dlg.hide()
-    return gtk.TRUE
+    return True
+
+  def on_no_conf_dlg_delete(self, *args):
+    sys.exit(0)
 
 #############################################################
 def initGlade():
